<?php

/**
 * Initialize Custom Post Type - Plombiers Theme
 */

function plombiers_custom_post_type() {

	$project_cpt = (plombiers_framework_active()) ? cs_get_option('theme_project_name') : '';
	$project_slug = (plombiers_framework_active()) ? cs_get_option('theme_project_slug') : '';
	$project_cpt_slug = (plombiers_framework_active()) ? cs_get_option('theme_project_cat_slug') : '';

	$base = (isset($project_cpt_slug) && $project_cpt_slug !== '') ? sanitize_title_with_dashes($project_cpt_slug) : ((isset($project_cpt) && $project_cpt !== '') ? strtolower($project_cpt) : 'project');
	$base_slug = (isset($project_slug) && $project_slug !== '') ? sanitize_title_with_dashes($project_slug) : ((isset($project_cpt) && $project_cpt !== '') ? strtolower($project_cpt) : 'project');
	$label = ucfirst((isset($project_cpt) && $project_cpt !== '') ? strtolower($project_cpt) : 'project');

	// Register custom post type - Project
	register_post_type('project',
		array(
			'labels' => array(
				'name' => $label,
				'singular_name' => sprintf(esc_html__('%s Post', 'plombiers-core' ), $label),
				'all_items' => sprintf(esc_html__('All %s', 'plombiers-core' ), $label),
				'add_new' => esc_html__('Add New', 'plombiers-core') ,
				'add_new_item' => sprintf(esc_html__('Add New %s', 'plombiers-core' ), $label),
				'edit' => esc_html__('Edit', 'plombiers-core') ,
				'edit_item' => sprintf(esc_html__('Edit %s', 'plombiers-core' ), $label),
				'new_item' => sprintf(esc_html__('New %s', 'plombiers-core' ), $label),
				'view_item' => sprintf(esc_html__('View %s', 'plombiers-core' ), $label),
				'search_items' => sprintf(esc_html__('Search %s', 'plombiers-core' ), $label),
				'not_found' => esc_html__('Nothing found in the Database.', 'plombiers-core') ,
				'not_found_in_trash' => esc_html__('Nothing found in Trash', 'plombiers-core') ,
				'parent_item_colon' => ''
			) ,
			'public' => true,
			'publicly_queryable' => true,
			'exclude_from_search' => false,
			'show_ui' => true,
			'query_var' => true,
			'menu_position' => 10,
			'menu_icon' => 'dashicons-portfolio',
			'rewrite' => array(
				'slug' => $base_slug,
				'with_front' => false
			),
			'has_archive' => true,
			'capability_type' => 'post',
			'hierarchical' => true,
			'supports' => array(
				'title',
				'editor',
				'author',
				'thumbnail',
				'excerpt',
				'trackbacks',
				'custom-fields',
				'comments',
				'revisions',
				'sticky',
				'page-attributes'
			)
		)
	);
	// Registered

	// Add Category Taxonomy for our Custom Post Type - Project
	register_taxonomy(
		'project_category',
		'project',
		array(
			'hierarchical' => true,
			'public' => true,
			'show_ui' => true,
			'show_admin_column' => true,
			'show_in_nav_menus' => true,
			'labels' => array(
				'name' => sprintf(esc_html__( '%s Categories', 'plombiers-core' ), $label),
				'singular_name' => sprintf(esc_html__('%s Category', 'plombiers-core'), $label),
				'search_items' =>  sprintf(esc_html__( 'Search %s Categories', 'plombiers-core'), $label),
				'all_items' => sprintf(esc_html__( 'All %s Categories', 'plombiers-core'), $label),
				'parent_item' => sprintf(esc_html__( 'Parent %s Category', 'plombiers-core'), $label),
				'parent_item_colon' => sprintf(esc_html__( 'Parent %s Category:', 'plombiers-core'), $label),
				'edit_item' => sprintf(esc_html__( 'Edit %s Category', 'plombiers-core'), $label),
				'update_item' => sprintf(esc_html__( 'Update %s Category', 'plombiers-core'), $label),
				'add_new_item' => sprintf(esc_html__( 'Add New %s Category', 'plombiers-core'), $label),
				'new_item_name' => sprintf(esc_html__( 'New %s Category Name', 'plombiers-core'), $label)
			),
			'rewrite' => array( 'slug' => $base . '_cat' ),
		)
	);

	$args = array(
		'hierarchical' => true,
		'public' => true,
		'show_ui' => true,
		'show_admin_column' => true,
		'show_in_nav_menus' => true,
		'show_tagcloud' => false,
	);

$service_slug = 'service';
$service = __('Service', 'plombiers-core');
// Register custom post type - service
	register_post_type('service',
		array(
			'labels' => array(
				'name' => $service,
				'singular_name' => sprintf(esc_html__('%s Post', 'plombiers-core' ), $service),
				'all_items' => sprintf(esc_html__('All %s', 'plombiers-core' ), $service),
				'add_new' => esc_html__('Add New', 'plombiers-core') ,
				'add_new_item' => sprintf(esc_html__('Add New %s', 'plombiers-core' ), $service),
				'edit' => esc_html__('Edit', 'plombiers-core') ,
				'edit_item' => sprintf(esc_html__('Edit %s', 'plombiers-core' ), $service),
				'new_item' => sprintf(esc_html__('New %s', 'plombiers-core' ), $service),
				'view_item' => sprintf(esc_html__('View %s', 'plombiers-core' ), $service),
				'search_items' => sprintf(esc_html__('Search %s', 'plombiers-core' ), $service),
				'not_found' => esc_html__('Nothing found in the Database.', 'plombiers-core') ,
				'not_found_in_trash' => esc_html__('Nothing found in Trash', 'plombiers-core') ,
				'parent_item_colon' => ''
			) ,
			'public' => true,
			'publicly_queryable' => true,
			'exclude_from_search' => false,
			'show_ui' => true,
			'query_var' => true,
			'menu_position' => 10,
			'menu_icon' => 'dashicons-portfolio',
			'rewrite' => array(
				'slug' => $service_slug,
				'with_front' => false
			),
			'has_archive' => true,
			'capability_type' => 'post',
			'hierarchical' => true,
			'supports' => array(
				'title',
				'editor',
				'author',
				'thumbnail',
				'excerpt',
				'trackbacks',
				'custom-fields',
				'comments',
				'revisions',
				'sticky',
				'page-attributes'
			)
		)
	);
	// Registered

	// Team - Start
	$team_slug = 'team';
	$teams = __('Teams', 'plombiers-core');

	// Register custom post type - Team
	register_post_type('team',
		array(
			'labels' => array(
				'name' => $teams,
				'singular_name' => sprintf(esc_html__('%s Post', 'plombiers-core' ), $teams),
				'all_items' => sprintf(esc_html__('%s', 'plombiers-core' ), $teams),
				'add_new' => esc_html__('Add New', 'plombiers-core') ,
				'add_new_item' => sprintf(esc_html__('Add New %s', 'plombiers-core' ), $teams),
				'edit' => esc_html__('Edit', 'plombiers-core') ,
				'edit_item' => sprintf(esc_html__('Edit %s', 'plombiers-core' ), $teams),
				'new_item' => sprintf(esc_html__('New %s', 'plombiers-core' ), $teams),
				'view_item' => sprintf(esc_html__('View %s', 'plombiers-core' ), $teams),
				'search_items' => sprintf(esc_html__('Search %s', 'plombiers-core' ), $teams),
				'not_found' => esc_html__('Nothing found in the Database.', 'plombiers-core') ,
				'not_found_in_trash' => esc_html__('Nothing found in Trash', 'plombiers-core') ,
				'parent_item_colon' => ''
			) ,
			'public' => true,
			'publicly_queryable' => true,
			'exclude_from_search' => false,
			'show_ui' => true,
			'query_var' => true,
			'menu_position' => 10,
			'menu_icon' => 'dashicons-groups',
			'rewrite' => array(
				'slug' => $team_slug,
				'with_front' => false
			),
			'has_archive' => true,
			'capability_type' => 'post',
			'hierarchical' => true,
			'supports' => array(
				'title',
				'editor',
				'thumbnail',
				'excerpt',
				'revisions',
				'sticky',
			)
		)
	);
	// Team - End

}



// Project Slug
function plombiers_custom_project_slug() {
	$project_cpt = (plombiers_framework_active()) ? cs_get_option('theme_project_name') : '';
	if ($project_cpt === '') $project_cp = 'project';
  $rules = get_option( 'rewrite_rules' );
  if ( ! isset( $rules['('.$project_cpt.')/(\d*)$'] ) ) {
		global $wp_rewrite;
		$wp_rewrite->flush_rules();
  }
}
add_action( 'cs_validate_save_after','plombiers_custom_project_slug' );

// After Theme Setup
function plombiers_custom_flush_rules() {
	// Enter post type function, so rewrite work within this function
	plombiers_custom_post_type();
	// Flush it
	flush_rewrite_rules();
}
register_activation_hook(__FILE__, 'plombiers_custom_flush_rules');
add_action('init', 'plombiers_custom_post_type');

// Avoid project post type as 404 page while it change
function plombiers_cpt_avoid_error_project() {
	$project_cpt = (plombiers_framework_active()) ? cs_get_option('theme_project_name') : '';
	if ($project_cpt === '') $project_cp = 'project';
	$set = get_option('post_type_rules_flased_' . $project_cpt);
	if ($set !== true){
		flush_rewrite_rules(false);
		update_option('post_type_rules_flased_' . $project_cpt,true);
	}
}
add_action('init', 'plombiers_cpt_avoid_error_project');

// Add Filter by Category in Project Type
add_action('restrict_manage_posts', 'plombiers_filter_project_categories');
function plombiers_filter_project_categories() {
	global $typenow;
	$post_type = 'project'; // Project post type
	$taxonomy  = 'project_category'; // Project category taxonomy
	if ($typenow == $post_type) {
		$selected      = isset($_GET[$taxonomy]) ? $_GET[$taxonomy] : '';
		$info_taxonomy = get_taxonomy($taxonomy);
		wp_dropdown_categories(array(
			'show_option_all' => sprintf(esc_html__("Show All %s", 'plombiers-core'), $info_taxonomy->label),
			'taxonomy'        => $taxonomy,
			'name'            => $taxonomy,
			'orderby'         => 'name',
			'selected'        => $selected,
			'show_count'      => true,
			'hide_empty'      => true,
		));
	};
}

// Project Search => ID to Term
add_filter('parse_query', 'plombiers_project_id_term_search');
function plombiers_project_id_term_search($query) {
	global $pagenow;
	$post_type = 'project'; // Project post type
	$taxonomy  = 'project_category'; // Project category taxonomy
	$q_vars    = &$query->query_vars;
	if ( $pagenow == 'edit.php' && isset($q_vars['post_type']) && $q_vars['post_type'] == $post_type && isset($q_vars[$taxonomy]) && is_numeric($q_vars[$taxonomy]) && $q_vars[$taxonomy] != 0 ) {
		$term = get_term_by('id', $q_vars[$taxonomy], $taxonomy);
		$q_vars[$taxonomy] = $term->slug;
	}
}

/* ---------------------------------------------------------------------------
 * Custom columns - Project
 * --------------------------------------------------------------------------- */
add_filter("manage_edit-project_columns", "plombiers_project_edit_columns");
function plombiers_project_edit_columns($columns) {
  $new_columns['cb'] = '<input type="checkbox" />';
  $new_columns['title'] = esc_html__('Title', 'plombiers-core' );
  $new_columns['thumbnail'] = esc_html__('Image', 'plombiers-core' );
  $new_columns['project_category'] = esc_html__('Categories', 'plombiers-core' );
  $new_columns['project_order'] = esc_html__('Order', 'plombiers-core' );
  $new_columns['date'] = esc_html__('Date', 'plombiers-core' );

  return $new_columns;
}
add_action('manage_project_posts_custom_column', 'plombiers_manage_project_columns', 10, 2);
function plombiers_manage_project_columns( $column_name ) {
  global $post;

  switch ($column_name) {

    /* If displaying the 'Image' column. */
    case 'thumbnail':
      echo get_the_post_thumbnail( $post->ID, array( 100, 100) );
    break;

    /* If displaying the 'Categories' column. */
    case 'project_category' :

      $terms = get_the_terms( $post->ID, 'project_category' );

      if ( !empty( $terms ) ) {

        $out = array();
        foreach ( $terms as $term ) {
            $out[] = sprintf( '<a href="%s">%s</a>',
            	esc_url( add_query_arg( array( 'post_type' => $post->post_type, 'project_category' => $term->slug ), 'edit.php' ) ),
            	esc_html( sanitize_term_field( 'name', $term->name, $term->term_id, 'project_category', 'display' ) )
            );
        }
        /* Join the terms, separating them with a comma. */
        echo join( ', ', $out );
      }

      /* If no terms were found, output a default message. */
      else {
        echo '&macr;';
      }

    break;

    case "project_order":
      echo $post->menu_order;
    break;

    /* Just break out of the switch statement for everything else. */
    default :
      break;
    break;

  }
}


/* ---------------------------------------------------------------------------
 * Custom columns - Team
 * --------------------------------------------------------------------------- */
add_filter("manage_edit-team_columns", "plombiers_team_edit_columns");
function plombiers_team_edit_columns($columns) {
  $new_columns['cb'] = '<input type="checkbox" />';
  $new_columns['title'] = esc_html__('Title', 'plombiers-core' );
  $new_columns['thumbnail'] = esc_html__('Image', 'plombiers-core' );
  $new_columns['name'] = esc_html__('Job Position', 'plombiers-core' );
  $new_columns['date'] = esc_html__('Date', 'plombiers-core' );

  return $new_columns;
}

add_action('manage_team_posts_custom_column', 'plombiers_manage_team_columns', 10, 2);
function plombiers_manage_team_columns( $column_name ) {
  global $post;

  switch ($column_name) {

    /* If displaying the 'Image' column. */
    case 'thumbnail':
      echo get_the_post_thumbnail( $post->ID, array( 100, 100) );
    break;

    case "name":
    	$team_options = get_post_meta( get_the_ID(), 'team_options', true );
      echo $team_options['team_job_position'];
    break;

    /* Just break out of the switch statement for everything else. */
    default :
      break;
    break;

  }
}
