<?php
/*
 * All Metabox related options for Plombiers theme.
 * Author & Copyright: IRSFoundation
 * URL: http://themeforest.net/user/irsfoundation
 */

function plombiers_metabox_options( $options ) {
  $sticky_header = cs_get_option( 'sticky_header' );
  $options      = array();

  // -----------------------------------------
  // Post Metabox Options                    -
  // -----------------------------------------
  $options[]    = array(
    'id'        => 'post_type_metabox',
    'title'     => esc_html__('Post Options', 'plombiers'),
    'post_type' => 'post',
    'context'   => 'normal',
    'priority'  => 'default',
    'sections'  => array(

      // All Post Formats
      array(
        'name'   => 'section_post_formats',
        'fields' => array(

          // Standard, Image
          array(
            'title' => 'Standard Image',
            'type'  => 'subheading',
            'content' => esc_html__('There is no Extra Option for this Post Format!', 'plombiers'),
            'wrap_class' => 'plombiers-minimal-heading hide-title',
          ),
          // Standard, Image

          // Gallery
          array(
            'type'    => 'notice',
            'title'   => 'Gallery Format',
            'wrap_class' => 'hide-title',
            'class'   => 'info cs-plombiers-heading',
            'content' => esc_html__('Gallery Format', 'plombiers')
          ),
          array(
            'id'          => 'gallery_post_format',
            'type'        => 'gallery',
            'title'       => esc_html__('Add Gallery', 'plombiers'),
            'add_title'   => esc_html__('Add Image(s)', 'plombiers'),
            'edit_title'  => esc_html__('Edit Image(s)', 'plombiers'),
            'clear_title' => esc_html__('Clear Image(s)', 'plombiers'),
          ),
          // Gallery
          array(
            'type'    => 'text',
            'title'   => esc_html__('Add Video URL', 'plombiers' ),
            'id'   => 'video_post_format',
            'desc' => esc_html__('Add youtube or vimeo video link', 'plombiers' )
          ),
          array(
            'id'          => 'audio_post_format',
            'type'        => 'textarea',
            'title'       => esc_html__('Enter audio iframe/embed code here :', 'plombiers'),
            'sanitize'  => true,
          ),

        ),
      ),

    ),
  );

  // -----------------------------------------
  // Page Metabox Options                    -
  // -----------------------------------------
  $options[]    = array(
    'id'        => 'page_type_metabox',
    'title'     => esc_html__('Page Custom Options', 'plombiers'),
    'post_type' => array('post', 'page', 'portfolio', 'product', 'team'),
    'context'   => 'normal',
    'priority'  => 'default',
    'sections'  => array(

      // Title Section
      array(
        'name'  => 'page_topbar_section',
        'title' => esc_html__('Top Bar', 'plombiers'),
        'icon'  => 'fa fa-minus',

        // Fields Start
        'fields' => array(

          array(
            'id'           => 'topbar_options',
            'type'         => 'image_select',
            'title'        => esc_html__('Topbar', 'plombiers'),
            'options'      => array(
              'default'     => PLOMBIERS_CS_IMAGES .'/topbar-default.png',
              'custom'      => PLOMBIERS_CS_IMAGES .'/topbar-custom.png',
              'hide_topbar' => PLOMBIERS_CS_IMAGES .'/topbar-hide.png',
            ),
            'attributes' => array(
              'data-depend-id' => 'hide_topbar_select',
            ),
            'radio'     => true,
            'default'   => 'default',
          ),
          array(
            'id'          => 'top_left',
            'type'        => 'textarea',
            'title'       => esc_html__('Top Left', 'plombiers'),
            'dependency'  => array('hide_topbar_select', '==', 'custom'),
            'shortcode'       => true,
          ),
          array(
            'id'          => 'top_right',
            'type'        => 'textarea',
            'title'       => esc_html__('Top Right', 'plombiers'),
            'dependency'  => array('hide_topbar_select', '==', 'custom'),
            'shortcode'       => true,
          ),
          array(
            'id'         => 'topbar_left_width',
            'type'       => 'text',
            'title'      => esc_html__('Top Left Width in %', 'plombiers'),
            'attributes' => array(
              'placeholder' => '50%'
            ),
            'dependency'  => array('hide_topbar_select', '==', 'custom'),
          ),
          array(
            'id'         => 'topbar_right_width',
            'type'       => 'text',
            'title'      => esc_html__('Top Right Width in %', 'plombiers'),
            'attributes' => array(
              'placeholder' => '50%'
            ),
            'dependency'  => array('hide_topbar_select', '==', 'custom'),
          ),
          array(
            'id'    => 'topbar_bg',
            'type'  => 'color_picker',
            'title' => esc_html__('Topbar Background Color', 'plombiers'),
            'dependency'  => array('hide_topbar_select', '==', 'custom'),
          ),
          array(
            'id'    => 'topbar_border',
            'type'  => 'color_picker',
            'title' => esc_html__('Topbar Border Color', 'plombiers'),
            'dependency'  => array('hide_topbar_select', '==', 'custom'),
          ),

        ), // End : Fields

      ), // Title Section

      // Header
      array(
        'name'  => 'header_section',
        'title' => esc_html__('Header', 'plombiers'),
        'icon'  => 'fa fa-bars',
        'fields' => array(

          array(
            'id'           => 'select_header_design',
            'type'         => 'image_select',
            'title'        => esc_html__('Select Header Design', 'plombiers'),
            'options'      => array(
              'default'     => PLOMBIERS_CS_IMAGES .'/hs-0.png',
              'style_one'   => PLOMBIERS_CS_IMAGES .'/hs-1.png',
              'style_two'   => PLOMBIERS_CS_IMAGES .'/hs-2.png',
            ),
            'attributes' => array(
              'data-depend-id' => 'header_design',
            ),
            'radio'     => true,
            'default'   => 'default',
            'info'      => esc_html__('Select your header design, following options will may differ based on your selection of header design.', 'plombiers'),
          ),
          array(
            'id'              => 'header_address_info',
            'title'           => esc_html__('Header Content', 'plombiers'),
            'desc'            => esc_html__('Add your header content here. Example : Address Details', 'plombiers'),
            'type'            => 'textarea',
            'shortcode'       => true,
            'dependency' => array('header_design', '==', 'style_two'),
          ),
          array(
            'id'              => 'header_queto_text',
            'title'           => esc_html__('Header Queto Text', 'plombiers'),
            'desc'            => esc_html__('Add your header  Queto Text : Text Details', 'plombiers'),
            'type'            => 'text',
            'shortcode'       => true,
            'dependency' => array('header_design', '==', 'style_two'),
          ),
          array(
            'id'              => 'header_queto_link',
            'title'           => esc_html__('Header Queto Link', 'plombiers'),
            'desc'            => esc_html__('Add your header  Queto Link : Text Details', 'plombiers'),
            'type'            => 'text',
            'shortcode'       => true,
            'dependency' => array('header_design', '==', 'style_two'),
          ),
          array(
            'id'             => 'choose_menu',
            'type'           => 'select',
            'title'          => esc_html__('Choose Menu', 'plombiers'),
            'desc'          => esc_html__('Choose custom menus for this page.', 'plombiers'),
            'options'        => 'menus',
            'default_option' => esc_html__('Select your menu', 'plombiers'),
          ),

          // Enable & Disable
          array(
            'type'    => 'notice',
            'class'   => 'info cs-plombiers-heading',
            'content' => esc_html__('Enable & Disable', 'plombiers'),
            'dependency' => array('header_design', '!=', 'default'),
          ),
        ),
      ),
      // Header

      // Banner & Title Area
      array(
        'name'  => 'banner_title_section',
        'title' => esc_html__('Banner & Title Area', 'plombiers'),
        'icon'  => 'fa fa-bullhorn',
        'fields' => array(

          array(
            'id'        => 'banner_type',
            'type'      => 'select',
            'title'     => esc_html__('Choose Banner Type', 'plombiers'),
            'options'   => array(
              'default-title'    => 'Default Title',
              'hide-title-area'   => 'Hide Title/Banner Area',
            ),
          ),
          array(
            'id'    => 'page_custom_title',
            'type'  => 'text',
            'title' => esc_html__('Custom Title', 'plombiers'),
            'attributes' => array(
              'placeholder' => esc_html__('Enter your custom title...', 'plombiers'),
            ),
            'dependency'   => array('banner_type', '==', 'default-title'),
          ),
          array(
            'id'        => 'title_area_spacings',
            'type'      => 'select',
            'title'     => esc_html__('Title Area Spacings', 'plombiers'),
            'options'   => array(
              'padding-none' => esc_html__('Default Spacing', 'plombiers'),
              'padding-custom' => esc_html__('Custom Padding', 'plombiers'),
            ),
            'dependency'   => array('banner_type', '==', 'default-title'),
          ),
          array(
            'id'    => 'title_top_spacings',
            'type'  => 'text',
            'title' => esc_html__('Top Spacing', 'plombiers'),
            'attributes'  => array( 'placeholder' => '100px' ),
            'dependency'  => array('banner_type|title_area_spacings', '==|==', 'default-title|padding-custom'),
          ),
          array(
            'id'    => 'title_bottom_spacings',
            'type'  => 'text',
            'title' => esc_html__('Bottom Spacing', 'plombiers'),
            'attributes'  => array( 'placeholder' => '100px' ),
            'dependency'  => array('banner_type|title_area_spacings', '==|==', 'default-title|padding-custom'),
          ),
          array(
            'id'    => 'title_area_bg',
            'type'  => 'background',
            'title' => esc_html__('Background', 'plombiers'),
            'dependency'   => array('banner_type', '==', 'default-title'),
          ),
          array(
            'id'    => 'titlebar_bg_overlay_color',
            'type'  => 'color_picker',
            'title' => esc_html__('Overlay Color', 'plombiers'),
            'dependency'   => array('banner_type', '==', 'default-title'),
          ),

        ),
      ),
      // Banner & Title Area

      // Content Section
      array(
        'name'  => 'page_content_options',
        'title' => esc_html__('Content Options', 'plombiers'),
        'icon'  => 'fa fa-file',

        'fields' => array(

          array(
            'id'        => 'content_spacings',
            'type'      => 'select',
            'title'     => esc_html__('Content Spacings', 'plombiers'),
            'options'   => array(
              'padding-none' => esc_html__('Default Spacing', 'plombiers'),
              'padding-custom' => esc_html__('Custom Padding', 'plombiers'),
            ),
            'desc' => esc_html__('Content area top and bottom spacings.', 'plombiers'),
          ),
          array(
            'id'    => 'content_top_spacings',
            'type'  => 'text',
            'title' => esc_html__('Top Spacing', 'plombiers'),
            'attributes'  => array( 'placeholder' => '100px' ),
            'dependency'  => array('content_spacings', '==', 'padding-custom'),
          ),
          array(
            'id'    => 'content_bottom_spacings',
            'type'  => 'text',
            'title' => esc_html__('Bottom Spacing', 'plombiers'),
            'attributes'  => array( 'placeholder' => '100px' ),
            'dependency'  => array('content_spacings', '==', 'padding-custom'),
          ),

        ), // End Fields
      ), // Content Section

      // Enable & Disable
      array(
        'name'  => 'hide_show_section',
        'title' => esc_html__('Enable & Disable', 'plombiers'),
        'icon'  => 'fa fa-toggle-on',
        'fields' => array(
          array(
            'id'    => 'hide_header',
            'type'  => 'switcher',
            'title' => esc_html__('Hide Header', 'plombiers'),
            'label' => esc_html__('Yes, Please do it.', 'plombiers'),
          ),
          array(
            'id'    => 'hide_breadcrumbs',
            'type'  => 'switcher',
            'title' => esc_html__('Hide Breadcrumbs', 'plombiers'),
            'label' => esc_html__('Yes, Please do it.', 'plombiers'),
          ),
          array(
            'id'    => 'hide_footer',
            'type'  => 'switcher',
            'title' => esc_html__('Hide Footer', 'plombiers'),
            'label' => esc_html__('Yes, Please do it.', 'plombiers'),
          ),
          array(
            'id'    => 'search_icon',
            'type'  => 'switcher',
            'title' => esc_html__('Search Icon', 'plombiers'),
            'info' => esc_html__('Turn On if you want to show search icon in navigation bar.', 'plombiers'),
            'default' => true,
          ),
          array(
            'id'    => 'sticky_header',
            'type'  => 'switcher',
            'title' => esc_html__('Sticky Header', 'plombiers'),
            'info' => esc_html__('Turn On if you want your naviagtion bar on sticky.', 'plombiers'),
            'default' => $sticky_header,
          ),
        ),
      ),
      // Enable & Disable

    ),
  );

  // -----------------------------------------
  // Page Layout
  // -----------------------------------------
  $options[]    = array(
    'id'        => 'subtitle_options',
    'title'     => esc_html__('Page Sub Title', 'plombiers'),
    'post_type' => 'page',
    'context'   => 'side',
    'priority'  => 'default',
     'sections'  => array(
      array(
        'name'   => 'subtitle_section',
        'fields' => array(
          array(
            'title'   => esc_html__('Sub Title', 'plombiers'),
            'id'      => 'irs_subtitle',
            'type'    => 'text',
          ),
        ),
      ),
    ),
  );
  $options[]    = array(
    'id'        => 'page_layout_options',
    'title'     => esc_html__('Page Layout', 'plombiers'),
    'post_type' => 'page',
    'context'   => 'side',
    'priority'  => 'default',
    'sections'  => array(

      array(
        'name'   => 'page_layout_section',
        'fields' => array(

          array(
            'id'        => 'page_layout',
            'type'      => 'image_select',
            'options'   => array(
              'full-width'    => PLOMBIERS_CS_IMAGES . '/page-1.png',
              'extra-width'   => PLOMBIERS_CS_IMAGES . '/page-2.png',
              'left-sidebar'  => PLOMBIERS_CS_IMAGES . '/page-3.png',
              'right-sidebar' => PLOMBIERS_CS_IMAGES . '/page-4.png',
            ),
            'attributes' => array(
              'data-depend-id' => 'page_layout',
            ),
            'default'    => 'full-width',
            'radio'      => true,
            'wrap_class' => 'text-center',
          ),
          array(
            'id'            => 'page_sidebar_widget',
            'type'           => 'select',
            'title'          => esc_html__('Sidebar Widget', 'plombiers'),
            'options'        => plombiers_registered_sidebars(),
            'default_option' => esc_html__('Select Widget', 'plombiers'),
            'dependency'   => array('page_layout', 'any', 'left-sidebar,right-sidebar'),
          ),
        ),
      ),

    ),
  );

  // -----------------------------------------
  // Testimonial
  // -----------------------------------------
  $options[]    = array(
    'id'        => 'testimonial_options',
    'title'     => esc_html__('Testimonial Client', 'plombiers'),
    'post_type' => 'testimonial',
    'context'   => 'side',
    'priority'  => 'default',
    'sections'  => array(

      array(
        'name'   => 'testimonial_option_section',
        'fields' => array(

          array(
            'id'      => 'testi_name',
            'type'    => 'text',
            'title'   => esc_html__('Name', 'plombiers'),
            'info'    => esc_html__('Enter client name', 'plombiers'),
          ),
          array(
            'id'      => 'testi_name_link',
            'type'    => 'text',
            'title'   => esc_html__('Name Link', 'plombiers'),
            'info'    => esc_html__('Enter client name link, if you want', 'plombiers'),
          ),
          array(
            'id'      => 'testi_pro',
            'type'    => 'text',
            'title'   => esc_html__('Profession', 'plombiers'),
            'info'    => esc_html__('Enter client profession', 'plombiers'),
          ),
          array(
            'id'      => 'testi_pro_link',
            'type'    => 'text',
            'title'   => esc_html__('Profession Link', 'plombiers'),
            'info'    => esc_html__('Enter client profession link', 'plombiers'),
          ),

        ),
      ),

    ),
  );


   // -----------------------------------------
  // Team
  // -----------------------------------------
  $options[]    = array(
    'id'        => 'team_options',
    'title'     => esc_html__('Team Meta', 'plombiers'),
    'post_type' => 'team',
    'context'   => 'side',
    'priority'  => 'default',
    'sections'  => array(
      array(
        'name'   => 'team_option_section',
        'fields' => array(
          array(
            'title'   => esc_html__('Member Welcome Text', 'plombiers'),
            'id'      => 'employee_welcome',
            'type'    => 'text',
          ),
          array(
            'title'   => esc_html__('Member Name', 'plombiers'),
            'id'      => 'employee_name',
            'type'    => 'text',
          ),
          array(
            'title'   => esc_html__('Job Position', 'plombiers'),
            'id'      => 'team_job_position',
            'type'    => 'text',
            'attributes' => array(
              'placeholder' => esc_html__('Eg : Financial Manager', 'plombiers'),
            ),
            'info'    => esc_html__('Enter the job position, in your company.', 'plombiers'),
          ),
          // Start fields
          array(
            'id'                  => 'team_infos',
            'type'                => 'group',
            'fields'              => array(
              array(
                'id'              => 'team_info_icon',
                'type'            => 'icon',
                'title'           => esc_html__('Social Icon', 'plombiers'),
              ),
              array(
                'id'              => 'team_info',
                'type'            => 'text',
                'title'           => esc_html__('Info', 'plombiers'),
              ),
            ),
            'button_title'        => esc_html__('Add Team info', 'plombiers'),
            'accordion_title'     => esc_html__('Team Info', 'plombiers'),
          ),
          // Start fields
          array(
            'id'                  => 'team_socials',
            'type'                => 'group',
            'fields'              => array(
              array(
                'id'              => 'team_social_icon',
                'type'            => 'icon',
                'title'           => esc_html__('Social Icon', 'plombiers'),
              ),
              array(
                'id'              => 'team_social_link',
                'type'            => 'text',
                'title'           => esc_html__('URL', 'plombiers'),
              ),
            ),
            'button_title'        => esc_html__('Add Social Icon', 'plombiers'),
            'accordion_title'     => esc_html__('Social Icons', 'plombiers'),
          ),
        ),
      ),
    ),
  );

// -----------------------------------------
  // Team
  // -----------------------------------------

  $options[]    = array(
    'id'        => 'team_page_options',
    'title'     => esc_html__('Team Meta', 'plombiers'),
    'post_type' => 'team',
    'context'   => 'normal',
    'priority'  => 'default',
    'sections'  => array(
      array(
        'name'   => 'team_metabox_section',
        'title' => esc_html__('Team Metabox Area', 'plombiers'),
        'icon'  => 'fa fa-bullhorn',
        'fields' => array(
         array(
              'id'              => 'progress_title',
              'type'            => 'text',
              'title'           => esc_html__('Progress Title', 'plombiers'),
            ),
          // Start fields
          array(
            'id'                  => 'progress_box',
            'type'                => 'group',
            'fields'              => array(
              array(
                'id'              => 'team_progress_title',
                'type'            => 'text',
                'title'           => esc_html__('Progress Title', 'plombiers'),
              ),
              array(
                'id'              => 'team_progress_parcent',
                'type'            => 'text',
                'title'           => esc_html__('Progress Parcent', 'plombiers'),
              ),
              array(
                'id'              => 'team_progress_color',
                'type'            => 'color_picker',
                'title'           => esc_html__('Progress Color', 'plombiers'),
              ),
            ),
            'button_title'        => esc_html__('Add Team Progress', 'plombiers'),
            'accordion_title'     => esc_html__('Team Progress', 'plombiers'),
          ),
          array(
            'id'             => 'choose_team',
            'type'           => 'select',
            'title'          => esc_html__('Choose Related Team', 'plombiers'),
            'desc'          => esc_html__('Choose Related Team for Single Team page.', 'plombiers'),
             'options'   => array(
              ''    => 'Choose Team ',
              'show-team'    => 'Show Releted Team',
              'hide-team' => 'Hide Releted Team',
            ),
          ),
        ),
      ),
    ),
  );


  // -----------------------------------------
  // Projects
  // -----------------------------------------
  $options[]    = array(
    'id'        => 'project_options',
    'title'     => esc_html__('Project Meta', 'plombiers'),
    'post_type' => 'project',
    'context'   => 'normal',
    'priority'  => 'default',
    'sections'  => array(
      array(
        'name'   => 'project_option_section',
        'fields' => array(
          array(
            'id'             => 'project_colunm',
            'type'           => 'select',
            'title'          => esc_html__('Choose Project Width', 'plombiers'),
            'options' => array(
              '' => 'Project Width',
              'col_twelve' => 'Width 100%',
              'col_eleven' => 'Width 91%',
              'col_ten' => 'Width 83%',
              'col_nine' => 'Width 75%',
              'col_eight' => 'Width 66%',
              'col_seven' => 'Width 58%',
              'col_six' => 'Width 50%',
              'col_five' => 'Width 41%',
              'col_three' => 'Width 33%',
              'col_four' => 'Width 25%',
              'col_two' => 'Width 16%',
              'col_one' => 'Width 8%',
            ),
          ),
          array(
            'id'           => 'single_project_image',
            'type'         => 'image',
            'title'        => esc_html__('Single Project Image', 'plombiers'),
            'add_title' => esc_html__('Add Single Project Image', 'plombiers'),
          ),
        ),
      ),

    ),
  );

  // -----------------------------------------
  // Projects
  // -----------------------------------------
  $options[]    = array(
    'id'        => 'project_meta_options',
    'title'     => esc_html__('Project Image', 'plombiers'),
    'post_type' => 'project',
    'context'   => 'side',
    'priority'  => 'default',
    'sections'  => array(
      array(
        'name'   => 'project_meta_section',
        'fields' => array(
          array(
            'id'           => 'project_icon',
            'type'         => 'icon',
            'title'        => esc_html__('Project icon', 'plombiers'),
            'add_title' => esc_html__('Add Project icon', 'plombiers'),
          ),
          array(
            'id'           => 'project_grid_image',
            'type'         => 'image',
            'title'        => esc_html__('Project Grid Image', 'plombiers'),
            'add_title' => esc_html__('Add Project Grid Image', 'plombiers'),
          ),
          array(
            'id'           => 'project_masonary_image',
            'type'         => 'image',
            'title'        => esc_html__('Project Masonry Image', 'plombiers'),
            'add_title' => esc_html__('Add Project Masonry Image', 'plombiers'),
          ),
        ),
      ),

    ),
  );

 // -----------------------------------------
  // services
  // -----------------------------------------
  $options[]    = array(
    'id'        => 'service_options',
    'title'     => esc_html__('Service Icon', 'plombiers'),
    'post_type' => 'service',
    'context'   => 'side',
    'priority'  => 'default',
    'sections'  => array(
      array(
        'name'   => 'service_option_section',
        'fields' => array(
          array(
            'id'           => 'service_icon',
            'type'         => 'icon',
            'title'        => esc_html__('service icon', 'plombiers'),
            'add_title' => esc_html__('Add service icon', 'plombiers'),
          ),
          array(
            'id'           => 'service_image',
            'type'         => 'image',
            'title'        => esc_html__('Service Single Image', 'plombiers'),
            'add_title' => esc_html__('Add service Single Image', 'plombiers'),
          ),
        ),
      ),

    ),
  );

  // -----------------------------------------
  // post options
  // -----------------------------------------
  $options[]    = array(
    'id'        => 'post_options',
    'title'     => esc_html__('Grid Image', 'plombiers'),
    'post_type' => 'post',
    'context'   => 'side',
    'priority'  => 'default',
    'sections'  => array(
      array(
        'name'   => 'post_option_section',
        'fields' => array(
          array(
            'id'           => 'post_grid_image',
            'type'         => 'image',
            'title'        => esc_html__('Post Grid Image', 'plombiers'),
            'add_title' => esc_html__('Add Post Grid Image', 'plombiers'),
          ),
        ),
      ),

    ),
  );


  return $options;

}
add_filter( 'cs_metabox_options', 'plombiers_metabox_options' );