<?php
/*
 * All Theme Options for Plombiers theme.
 * Author & Copyright: IRSFoundation
 * URL: http://themeforest.net/user/irsfoundation
 */

function plombiers_settings( $settings ) {

  $settings           = array(
    'menu_title'      => PLOMBIERS_NAME . esc_html__(' Options', 'plombiers'),
    'menu_slug'       => sanitize_title(PLOMBIERS_NAME) . '_options',
    'menu_type'       => 'menu',
    'menu_icon'       => 'dashicons-awards',
    'menu_position'   => '4',
    'ajax_save'       => false,
    'show_reset_all'  => true,
    'framework_title' => PLOMBIERS_NAME .' <small>V-'. PLOMBIERS_VERSION .' by <a href="'. PLOMBIERS_BRAND_URL .'" target="_blank">'. PLOMBIERS_BRAND_NAME .'</a></small>',
  );

  return $settings;

}
add_filter( 'cs_framework_settings', 'plombiers_settings' );

// Theme Framework Options
function plombiers_options( $options ) {

  $options      = array(); // remove old options

  // ------------------------------
  // Branding
  // ------------------------------
  $options[]   = array(
    'name'     => 'plombiers_theme_branding',
    'title'    => esc_html__('Brand', 'plombiers'),
    'icon'     => 'fa fa-trophy',
    'sections' => array(

      // brand logo tab
      array(
        'name'     => 'brand_logo',
        'title'    => esc_html__('Logo', 'plombiers'),
        'icon'     => 'fa fa-star',
        'fields'   => array(

          // Site Logo
          array(
            'type'    => 'notice',
            'class'   => 'info cs-plombiers-heading',
            'content' => esc_html__('Site Logo', 'plombiers')
          ),
          array(
            'id'    => 'default_logo',
            'type'  => 'image',
            'title' => esc_html__('Default Logo', 'plombiers'),
            'info'  => esc_html__('Upload your default logo here. If you not upload, then site title will load in this logo location.', 'plombiers'),
            'add_title' => esc_html__('Add Logo', 'plombiers'),
          ),
          array(
            'type'    => 'notice',
            'class'   => 'info cs-plombiers-heading',
            'content' => esc_html__('Transparent Header', 'plombiers')
          ),
          array(
            'id'    => 'transparent_logo_default',
            'type'  => 'image',
            'title' => esc_html__('Transparent Logo', 'plombiers'),
            'info'  => esc_html__('Upload your transparent header logo here. This logo is used in transparent header by enabled in each pages.', 'plombiers'),
            'add_title' => esc_html__('Add Transparent Logo', 'plombiers'),
          ),
          // WordPress Admin Logo
          array(
            'type'    => 'notice',
            'class'   => 'info cs-plombiers-heading',
            'content' => esc_html__('WordPress Admin Logo', 'plombiers')
          ),
          array(
            'id'    => 'brand_logo_wp',
            'type'  => 'image',
            'title' => esc_html__('Login logo', 'plombiers'),
            'info'  => esc_html__('Upload your WordPress login page logo here.', 'plombiers'),
            'add_title' => esc_html__('Add Login Logo', 'plombiers'),
          ),
        ) // end: fields
      ), // end: section

      // Fav
      array(
        'name'     => 'brand_fav',
        'title'    => esc_html__('Fav Icon', 'plombiers'),
        'icon'     => 'fa fa-anchor',
        'fields'   => array(

            // -----------------------------
            // Begin: Fav
            // -----------------------------
            array(
              'id'    => 'brand_fav_icon',
              'type'  => 'image',
              'title' => esc_html__('Fav Icon', 'plombiers'),
              'info'  => esc_html__('Upload your site fav icon, size should be 16x16.', 'plombiers'),
              'add_title' => esc_html__('Add Fav Icon', 'plombiers'),
            ),
            array(
              'id'    => 'iphone_icon',
              'type'  => 'image',
              'title' => esc_html__('Apple iPhone icon', 'plombiers'),
              'info'  => esc_html__('Icon for Apple iPhone (57px x 57px). This icon is used for Bookmark on Home screen.', 'plombiers'),
              'add_title' => esc_html__('Add iPhone Icon', 'plombiers'),
            ),
            array(
              'id'    => 'iphone_retina_icon',
              'type'  => 'image',
              'title' => esc_html__('Apple iPhone retina icon', 'plombiers'),
              'info'  => esc_html__('Icon for Apple iPhone retina (114px x114px). This icon is used for Bookmark on Home screen.', 'plombiers'),
              'add_title' => esc_html__('Add iPhone Retina Icon', 'plombiers'),
            ),
            array(
              'id'    => 'ipad_icon',
              'type'  => 'image',
              'title' => esc_html__('Apple iPad icon', 'plombiers'),
              'info'  => esc_html__('Icon for Apple iPad (72px x 72px). This icon is used for Bookmark on Home screen.', 'plombiers'),
              'add_title' => esc_html__('Add iPad Icon', 'plombiers'),
            ),
            array(
              'id'    => 'ipad_retina_icon',
              'type'  => 'image',
              'title' => esc_html__('Apple iPad retina icon', 'plombiers'),
              'info'  => esc_html__('Icon for Apple iPad retina (144px x 144px). This icon is used for Bookmark on Home screen.', 'plombiers'),
              'add_title' => esc_html__('Add iPad Retina Icon', 'plombiers'),
            ),

        ) // end: fields
      ), // end: section

    ),
  );

  // ------------------------------
  // Layout
  // ------------------------------
  $options[] = array(
    'name'   => 'theme_layout',
    'title'  => esc_html__('Layout', 'plombiers'),
    'icon'   => 'fa fa-file-text'
  );

  $options[]      = array(
    'name'        => 'theme_general',
    'title'       => esc_html__('General', 'plombiers'),
    'icon'        => 'fa fa-wrench',

    // begin: fields
    'fields'      => array(

      // -----------------------------
      // Begin: Responsive
      // -----------------------------
      array(
        'id'    => 'theme_responsive',
        'type'  => 'switcher',
        'title' => esc_html__('Responsive', 'plombiers'),
        'info' => esc_html__('Turn off if you don\'t want your site to be responsive.', 'plombiers'),
        'default' => true,
      ),
       array(
        'id'    => 'active_preloader',
        'type'  => 'switcher',
        'title' => esc_html__('Preloader', 'plombiers'),
        'info' => esc_html__('Turn off if you don\'t want preloader in your site.', 'plombiers'),
        'default' => true,
      ),
      array(
        'id'    => 'preloader_icon',
        'type'  => 'image',
        'title' => esc_html__('Preloader Icon', 'plombiers'),
        'dependency' => array( 'active_preloader', '==', 'true' ),
      ),
      array(
        'id'    => 'theme_layout_width',
        'type'  => 'image_select',
        'title' => esc_html__('Full Width & Extra Width', 'plombiers'),
        'info' => esc_html__('Boxed or Fullwidth? Choose your site layout width. Default : Full Width', 'plombiers'),
        'options'      => array(
          'container'    => PLOMBIERS_CS_IMAGES .'/boxed-width.jpg',
          'container-fluid'    => PLOMBIERS_CS_IMAGES .'/full-width.jpg',
        ),
        'default'      => 'container-fluid',
        'radio'      => true,
      ),
      array(
        'type'    => 'notice',
        'class'   => 'info cs-plombiers-heading',
        'content' => esc_html__('Background Options', 'plombiers'),
        'dependency' => array( 'theme_layout_width_container', '==', 'true' ),
      ),
      array(
        'id'             => 'theme_layout_bg_type',
        'type'           => 'select',
        'title'          => esc_html__('Background Type', 'plombiers'),
        'options'        => array(
          'bg-image' => esc_html__('Image', 'plombiers'),
          'bg-pattern' => esc_html__('Pattern', 'plombiers'),
        ),
        'dependency' => array( 'theme_layout_width_container', '==', 'true' ),
      ),
      array(
        'id'    => 'theme_layout_bg_pattern',
        'type'  => 'image_select',
        'title' => esc_html__('Background Pattern', 'plombiers'),
        'info' => esc_html__('Select background pattern', 'plombiers'),
        'options'      => array(
          'pattern-1'    => PLOMBIERS_CS_IMAGES . '/pattern-1.png',
          'pattern-2'    => PLOMBIERS_CS_IMAGES . '/pattern-2.png',
          'pattern-3'    => PLOMBIERS_CS_IMAGES . '/pattern-3.png',
          'pattern-4'    => PLOMBIERS_CS_IMAGES . '/pattern-4.png',
          'custom-pattern'  => PLOMBIERS_CS_IMAGES . '/pattern-5.png',
        ),
        'default'      => 'pattern-1',
        'radio'      => true,
        'dependency' => array( 'theme_layout_width_container|theme_layout_bg_type', '==|==', 'true|bg-pattern' ),
      ),
      array(
        'id'      => 'custom_bg_pattern',
        'type'    => 'upload',
        'title'   => esc_html__('Custom Pattern', 'plombiers'),
        'dependency' => array( 'theme_layout_width_container|theme_layout_bg_type|theme_layout_bg_pattern_custom-pattern', '==|==|==', 'true|bg-pattern|true' ),
        'info' => wp_kses( __('Select your custom background pattern. <br />Note, background pattern image will be repeat in all x and y axis. So, please consider all repeatable area will perfectly fit your custom patterns.', 'plombiers'), array( 'br' => array() ) ),
      ),
      array(
        'id'      => 'theme_layout_bg',
        'type'    => 'background',
        'title'   => esc_html__('Background', 'plombiers'),
        'dependency' => array( 'theme_layout_width_container|theme_layout_bg_type', '==|==', 'true|bg-image' ),
      ),
      array(
        'id'    => 'theme_page_comments',
        'type'  => 'switcher',
        'title' => esc_html__('Hide Page Comments?', 'plombiers'),
        'info' => esc_html__('Turn On if you want to hide comments in your pages.', 'plombiers'),
        'default' => false,
      ),


    ), // end: fields

  );

  // ------------------------------
  // Header Sections
  // ------------------------------
  $options[]   = array(
    'name'     => 'theme_header_tab',
    'title'    => esc_html__('Header', 'plombiers'),
    'icon'     => 'fa fa-bars',
    'sections' => array(

      // header design tab
      array(
        'name'     => 'header_design_tab',
        'title'    => esc_html__('Design', 'plombiers'),
        'icon'     => 'fa fa-magic',
        'fields'   => array(

          // Header Select
          array(
            'id'           => 'select_header_design',
            'type'         => 'image_select',
            'title'        => esc_html__('Select Header Design', 'plombiers'),
            'options'      => array(
              'style_one'    => PLOMBIERS_CS_IMAGES .'/hs-1.png',
              'style_two'    => PLOMBIERS_CS_IMAGES .'/hs-2.png',
            ),
            'attributes' => array(
              'data-depend-id' => 'header_design',
            ),
            'radio'        => true,
            'default'   => 'style_one',
            'info' => esc_html__('Select your header design, following options will may differ based on your selection of header design.', 'plombiers'),
          ),
          array(
            'id'              => 'header_address_info',
            'title'           => esc_html__('Header Content', 'plombiers'),
            'desc'            => esc_html__('Add your header content here. Example : Address Details', 'plombiers'),
            'type'            => 'textarea',
            'shortcode'       => true,
            'dependency' => array('header_design', '==', 'style_two'),
          ),
          array(
            'id'              => 'header_queto_text',
            'title'           => esc_html__('Header Queto Text', 'plombiers'),
            'desc'            => esc_html__('Add your header  Queto Text : Text Details', 'plombiers'),
            'type'            => 'text',
            'shortcode'       => true,
            'dependency' => array('header_design', '==', 'style_two'),
          ),
          array(
            'id'              => 'header_queto_link',
            'title'           => esc_html__('Header Queto Link', 'plombiers'),
            'desc'            => esc_html__('Add your header  Queto Link : Text Details', 'plombiers'),
            'type'            => 'text',
            'shortcode'       => true,
            'dependency' => array('header_design', '==', 'style_two'),
          ),
          // Header Select

          // Extra's
          array(
            'type'    => 'notice',
            'class'   => 'info cs-plombiers-heading',
            'content' => esc_html__('Extra\'s', 'plombiers'),
          ),
          array(
            'id'    => 'sticky_header',
            'type'  => 'switcher',
            'title' => esc_html__('Sticky Header', 'plombiers'),
            'info' => esc_html__('Turn On if you want your naviagtion bar on sticky.', 'plombiers'),
            'default' => true,
          ),
          array(
            'id'    => 'search_icon',
            'type'  => 'switcher',
            'title' => esc_html__('Search Icon', 'plombiers'),
            'info' => esc_html__('Turn On if you want to show search icon in navigation bar.', 'plombiers'),
            'default' => true,
          ),
        )
      ),

      // header top bar
      array(
        'name'     => 'header_top_bar_tab',
        'title'    => esc_html__('Top Bar', 'plombiers'),
        'icon'     => 'fa fa-minus',
        'fields'   => array(

          array(
            'id'          => 'top_bar',
            'type'        => 'switcher',
            'title'       => esc_html__('Hide Top Bar', 'plombiers'),
            'on_text'     => esc_html__('Yes', 'plombiers'),
            'off_text'    => esc_html__('No', 'plombiers'),
            'default'     => false,
          ),
          array(
            'id'          => 'top_left',
            'title'       => esc_html__('Top Left Block', 'plombiers'),
            'desc'        => esc_html__('Top bar left block.', 'plombiers'),
            'type'        => 'textarea',
            'shortcode'   => true,
            'dependency'  => array('top_bar', '==', false),
          ),
          array(
            'id'          => 'top_right',
            'title'       => esc_html__('Top Right Block', 'plombiers'),
            'desc'        => esc_html__('Top bar right block.', 'plombiers'),
            'type'        => 'textarea',
            'shortcode'   => true,
            'dependency'  => array('top_bar', '==', false),
          ),

          array(
            'id'          => 'topbar_left_width',
            'type'        => 'text',
            'title'       => esc_html__('Top Left Width in %', 'plombiers'),
            'attributes'  => array(
              'placeholder' => '50%'
            ),
            'dependency'  => array('top_bar', '==', false),
          ),
          array(
            'id'          => 'topbar_right_width',
            'type'        => 'text',
            'title'       => esc_html__('Top Right Width in %', 'plombiers'),
            'attributes'  => array(
              'placeholder' => '50%'
            ),
            'dependency'  => array('top_bar', '==', false),
          ),

        )
      ),

      // header banner
      array(
        'name'     => 'header_banner_tab',
        'title'    => esc_html__('Title Bar (or) Banner', 'plombiers'),
        'icon'     => 'fa fa-bullhorn',
        'fields'   => array(

          // Title Area
          array(
            'type'    => 'notice',
            'class'   => 'info cs-plombiers-heading',
            'content' => esc_html__('Title Area', 'plombiers')
          ),
          array(
            'id'      => 'need_title_bar',
            'type'    => 'switcher',
            'title'   => esc_html__('Title Bar', 'plombiers'),
            'label'   => esc_html__('If you want title bar in your sub-pages, please turn this ON.', 'plombiers'),
            'default'    => true,
          ),
          array(
            'id'             => 'title_bar_padding',
            'type'           => 'select',
            'title'          => esc_html__('Padding Spaces Top & Bottom', 'plombiers'),
            'options'        => array(
              'padding-none' => esc_html__('Default Spacing', 'plombiers'),
              'padding-custom' => esc_html__('Custom Padding', 'plombiers'),
            ),
            'dependency'   => array( 'need_title_bar', '==', 'true' ),
          ),
          array(
            'id'             => 'titlebar_top_padding',
            'type'           => 'text',
            'title'          => esc_html__('Padding Top', 'plombiers'),
            'attributes' => array(
              'placeholder'     => '100px',
            ),
            'dependency'   => array( 'title_bar_padding', '==', 'padding-custom' ),
          ),
          array(
            'id'             => 'titlebar_bottom_padding',
            'type'           => 'text',
            'title'          => esc_html__('Padding Bottom', 'plombiers'),
            'attributes' => array(
              'placeholder'     => '100px',
            ),
            'dependency'   => array( 'title_bar_padding', '==', 'padding-custom' ),
          ),

          array(
            'type'    => 'notice',
            'class'   => 'info cs-plombiers-heading',
            'content' => esc_html__('Background Options', 'plombiers'),
            'dependency' => array( 'need_title_bar', '==', 'true' ),
          ),
          array(
            'id'      => 'titlebar_bg',
            'type'    => 'background',
            'title'   => esc_html__('Background', 'plombiers'),
            'dependency' => array( 'need_title_bar', '==', 'true' ),
          ),
          array(
            'id'      => 'titlebar_bg_overlay_color',
            'type'    => 'color_picker',
            'title'   => esc_html__('Overlay Color', 'plombiers'),
            'dependency' => array( 'need_title_bar', '==', 'true' ),
          ),

          array(
            'type'    => 'notice',
            'class'   => 'info cs-plombiers-heading',
            'content' => esc_html__('Breadcrumbs', 'plombiers'),
          ),
          array(
            'id'      => 'need_breadcrumbs',
            'type'    => 'switcher',
            'title'   => esc_html__('Breadcrumbs', 'plombiers'),
            'label'   => esc_html__('If you want Breadcrumbs in your banner, please turn this ON.', 'plombiers'),
            'default'    => true,
          ),

        )
      ),

    ),
  );

  // ------------------------------
  // Footer Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'footer_section',
    'title'    => esc_html__('Footer', 'plombiers'),
    'icon'     => 'fa fa-ellipsis-h',
    'sections' => array(

      // footer widgets
      array(
        'name'     => 'footer_widgets_tab',
        'title'    => esc_html__('Widget Area', 'plombiers'),
        'icon'     => 'fa fa-th',
        'fields'   => array(

          // Footer Widget Block
          array(
            'type'    => 'notice',
            'class'   => 'info cs-plombiers-heading',
            'content' => esc_html__('Footer Widget Block', 'plombiers')
          ),
           array(
            'id'    => 'footer_bg',
            'type'  => 'image',
            'title' => esc_html__('Footer Background', 'plombiers'),
            'info'  => esc_html__('Upload your Footer Background here.', 'plombiers'),
            'add_title' => esc_html__('Add Logo', 'plombiers'),
          ),
          array(
            'id'    => 'footer_widget_block',
            'type'  => 'switcher',
            'title' => esc_html__('Enable Widget Block', 'plombiers'),
            'info' => wp_kses( __('If you turn this ON, then Goto : Appearance > Widgets. There you can see <strong>Footer Widget 1,2,3 or 4</strong> Widget Area, add your widgets there.', 'plombiers'), array( 'br' => array() ) ),
            'default' => true,
          ),
          array(
            'id'    => 'footer_widget_layout',
            'type'  => 'image_select',
            'title' => esc_html__('Widget Layouts', 'plombiers'),
            'info' => esc_html__('Choose your footer widget theme-layouts.', 'plombiers'),
            'default' => 4,
            'options' => array(
              1   => PLOMBIERS_CS_IMAGES . '/footer/footer-1.png',
              2   => PLOMBIERS_CS_IMAGES . '/footer/footer-2.png',
              3   => PLOMBIERS_CS_IMAGES . '/footer/footer-3.png',
              4   => PLOMBIERS_CS_IMAGES . '/footer/footer-4.png',
              5   => PLOMBIERS_CS_IMAGES . '/footer/footer-5.png',
              6   => PLOMBIERS_CS_IMAGES . '/footer/footer-6.png',
              7   => PLOMBIERS_CS_IMAGES . '/footer/footer-7.png',
              8   => PLOMBIERS_CS_IMAGES . '/footer/footer-8.png',
              9   => PLOMBIERS_CS_IMAGES . '/footer/footer-9.png',
            ),
            'radio'       => true,
            'dependency'  => array('footer_widget_block', '==', true),
          ),

        )
      ),

      // footer copyright
      array(
        'name'     => 'footer_copyright_tab',
        'title'    => esc_html__('Copyright Bar', 'plombiers'),
        'icon'     => 'fa fa-copyright',
        'fields'   => array(

          // Copyright
          array(
            'type'    => 'notice',
            'class'   => 'info cs-plombiers-heading',
            'content' => esc_html__('Copyright Layout', 'plombiers'),
          ),
          array(
            'id'    => 'need_copyright',
            'type'  => 'switcher',
            'title' => esc_html__('Enable Copyright Section', 'plombiers'),
            'default' => true,
          ),
          array(
            'id'    => 'copyright_text',
            'type'  => 'textarea',
            'title' => esc_html__('Copyright Text', 'plombiers'),
            'shortcode' => true,
            'dependency' => array('need_copyright', '==', true),
            'after'       => 'Helpful shortcodes: [current_year] [home_url] or any shortcode.',
          ),
        )
      ),

    ),
  );

  // ------------------------------
  // Design
  // ------------------------------
  $options[] = array(
    'name'   => 'theme_design',
    'title'  => esc_html__('Design', 'plombiers'),
    'icon'   => 'fa fa-magic'
  );

  // ------------------------------
  // color section
  // ------------------------------
  $options[]   = array(
    'name'     => 'theme_color_section',
    'title'    => esc_html__('Colors', 'plombiers'),
    'icon'     => 'fa fa-eyedropper',
    'fields' => array(

      array(
        'type'    => 'heading',
        'content' => esc_html__('Color Options', 'plombiers'),
      ),
       array(
        'type'    => 'subheading',
        'wrap_class' => 'color-tab-content',
        'content' => wp_kses( __('All color options are available in our theme customizer. The reason of we used customizer options for color section is because, you can choose each part of color from there and see the changes instantly using customizer. <br /><br />Highly customizable colors are in <strong>Appearance > Customize</strong>', 'plombiers'), array( 'br' => array(), 'strong' => array() ) ),
      ),

    ),
  );

  // ------------------------------
  // Typography section
  // ------------------------------
  $options[]   = array(
    'name'     => 'theme_typo_section',
    'title'    => esc_html__('Typography', 'plombiers'),
    'icon'     => 'fa fa-header',
    'fields' => array(

      // Start fields
      array(
        'id'                  => 'typography',
        'type'                => 'group',
        'fields'              => array(
          array(
            'id'              => 'title',
            'type'            => 'text',
            'title'           => esc_html__('Title', 'plombiers'),
          ),
          array(
            'id'              => 'selector',
            'type'            => 'textarea',
            'title'           => esc_html__('Selector', 'plombiers'),
            'info'           => esc_html__('Enter css selectors like : <strong>body, .custom-class</strong>', 'plombiers'),
          ),
          array(
            'id'              => 'font',
            'type'            => 'typography',
            'title'           => esc_html__('Font Family', 'plombiers'),
          ),
          array(
            'id'              => 'size',
            'type'            => 'text',
            'title'           => esc_html__('Font Size', 'plombiers'),
          ),
          array(
            'id'              => 'line_height',
            'type'            => 'text',
            'title'           => esc_html__('Line-Height', 'plombiers'),
          ),
          array(
            'id'              => 'css',
            'type'            => 'textarea',
            'title'           => esc_html__('Custom CSS', 'plombiers'),
          ),
        ),
        'button_title'        => esc_html__('Add New Typography', 'plombiers'),
        'accordion_title'     => esc_html__('New Typography', 'plombiers'),
      ),

      // Subset
      array(
        'id'                  => 'subsets',
        'type'                => 'select',
        'title'               => esc_html__('Subsets', 'plombiers'),
        'class'               => 'chosen',
        'options'             => array(
          'latin'             => 'latin',
          'latin-ext'         => 'latin-ext',
          'cyrillic'          => 'cyrillic',
          'cyrillic-ext'      => 'cyrillic-ext',
          'greek'             => 'greek',
          'greek-ext'         => 'greek-ext',
          'vietnamese'        => 'vietnamese',
          'devanagari'        => 'devanagari',
          'khmer'             => 'khmer',
        ),
        'attributes'         => array(
          'data-placeholder' => 'Subsets',
          'multiple'         => 'multiple',
          'style'            => 'width: 200px;'
        ),
        'default'             => array( 'latin' ),
      ),

      array(
        'id'                  => 'font_weight',
        'type'                => 'select',
        'title'               => esc_html__('Font Weights', 'plombiers'),
        'class'               => 'chosen',
        'options'             => array(
          '100'   => 'Thin 100',
          '100i'  => 'Thin 100 Italic',
          '200'   => 'Extra Light 200',
          '200i'  => 'Extra Light 200 Italic',
          '300'   => 'Light 300',
          '300i'  => 'Light 300 Italic',
          '400'   => 'Regular 400',
          '400i'  => 'Regular 400 Italic',
          '500'   => 'Medium 500',
          '500i'  => 'Medium 500 Italic',
          '600'   => 'Semi Bold 600',
          '600i'  => 'Semi Bold 600 Italic',
          '700'   => 'Bold 700',
          '700i'  => 'Bold 700 Italic',
          '800'   => 'Extra Bold 800',
          '800i'  => 'Extra Bold 800 Italic',
          '900'   => 'Black 900',
          '900i'  => 'Black 900 Italic',
        ),
        'attributes'         => array(
          'data-placeholder' => 'Font Weight',
          'multiple'         => 'multiple',
          'style'            => 'width: 200px;'
        ),
        'default'             => array( '400' ),
      ),

      // Custom Fonts Upload
      array(
        'id'                 => 'font_family',
        'type'               => 'group',
        'title'              => 'Upload Custom Fonts',
        'button_title'       => 'Add New Custom Font',
        'accordion_title'    => 'Adding New Font',
        'accordion'          => true,
        'desc'               => 'It is simple. Only add your custom fonts and click to save. After you can check "Font Family" selector. Do not forget to Save!',
        'fields'             => array(

          array(
            'id'             => 'name',
            'type'           => 'text',
            'title'          => 'Font-Family Name',
            'attributes'     => array(
              'placeholder'  => 'for eg. Arial'
            ),
          ),

          array(
            'id'             => 'ttf',
            'type'           => 'upload',
            'title'          => 'Upload .ttf <small><i>(optional)</i></small>',
            'settings'       => array(
              'upload_type'  => 'font',
              'insert_title' => 'Use this Font-Format',
              'button_title' => 'Upload <i>.ttf</i>',
            ),
          ),

          array(
            'id'             => 'eot',
            'type'           => 'upload',
            'title'          => 'Upload .eot <small><i>(optional)</i></small>',
            'settings'       => array(
              'upload_type'  => 'font',
              'insert_title' => 'Use this Font-Format',
              'button_title' => 'Upload <i>.eot</i>',
            ),
          ),

          array(
            'id'             => 'svg',
            'type'           => 'upload',
            'title'          => 'Upload .svg <small><i>(optional)</i></small>',
            'settings'       => array(
              'upload_type'  => 'font',
              'insert_title' => 'Use this Font-Format',
              'button_title' => 'Upload <i>.svg</i>',
            ),
          ),

          array(
            'id'             => 'otf',
            'type'           => 'upload',
            'title'          => 'Upload .otf <small><i>(optional)</i></small>',
            'settings'       => array(
              'upload_type'  => 'font',
              'insert_title' => 'Use this Font-Format',
              'button_title' => 'Upload <i>.otf</i>',
            ),
          ),

          array(
            'id'             => 'woff',
            'type'           => 'upload',
            'title'          => 'Upload .woff <small><i>(optional)</i></small>',
            'settings'       => array(
              'upload_type'  => 'font',
              'insert_title' => 'Use this Font-Format',
              'button_title' => 'Upload <i>.woff</i>',
            ),
          ),
         array(
            'id'             => 'css',
            'type'           => 'textarea',
            'title'          => wp_kses( __('Extra CSS Style <small><i>(optional)</i></small>', 'plombiers'), array( 'i' => array(), 'small' => array() ) ),
            'attributes'     => array(
              'placeholder'  => 'for eg. font-weight: normal;'
            ),
          ),

        ),
      ),
      // End All field

    ),
  );

  // ------------------------------
  // Pages
  // ------------------------------
  $options[] = array(
    'name'   => 'theme_pages',
    'title'  => esc_html__('Pages', 'plombiers'),
    'icon'   => 'fa fa-files-o'
  );

  // ------------------------------
  // Project Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'project_section',
    'title'    => esc_html__('Project', 'plombiers'),
    'icon'     => 'fa fa-briefcase',
    'fields' => array(

      // portfolio name change
      array(
        'type'    => 'notice',
        'class'   => 'info cs-plombiers-heading',
        'content' => esc_html__('Name Change', 'plombiers')
      ),
      array(
        'id'      => 'project_sidebar',
        'type'    => 'select',
        'title'   => esc_html__('Please Select Single Project Sidebar', 'plombiers'),
        'options'        => array(
          'sidebar-right' => esc_html__('Right', 'plombiers'),
          'sidebar-left' => esc_html__('Left', 'plombiers'),
          'sidebar-hide' => esc_html__('Hide', 'plombiers'),
        ),
        'default_option' => 'Select sidebar position',
      ),
    ),
  );


  // ------------------------------
  // Team Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'team_section',
    'title'    => esc_html__('Team', 'plombiers'),
    'icon'     => 'fa fa-users',
    'fields' => array(

      // Team Start
      array(
        'type'    => 'notice',
        'class'   => 'info cs-plombiers-heading',
        'content' => esc_html__('Team Single', 'plombiers')
      ),
      array(
        'id'    => 'team_featured_image',
        'type'  => 'switcher',
        'title' => esc_html__('Hide Featured Image?', 'plombiers'),
        'info' => esc_html__('If need to show featured image from single blog post page, please turn this OFF.', 'plombiers'),
        'default' => false,
      ),
      array(
        'id'      => 'team_top_spacing',
        'type'    => 'text',
        'title'   => esc_html__('Top Spacing', 'plombiers'),
        'info'   => esc_html__('Enter value in px, for team single pages top value.', 'plombiers'),
        'default' => '60px',
      ),
      array(
        'id'      => 'team_bottom_spacing',
        'type'    => 'text',
        'title'   => esc_html__('Bottom Spacing', 'plombiers'),
        'info'   => esc_html__('Enter value in px, for team single pages bottom value.', 'plombiers'),
        'default' => '0px',
      ),
      array(
        'id'             => 'choose_team',
        'type'           => 'select',
        'title'          => esc_html__('Choose Related Team', 'plombiers'),
        'desc'          => esc_html__('Choose Related Team for Single Team page.', 'plombiers'),
         'options'   => array(
          'show-team'    => 'Show Releted Team',
          'hide-team' => 'Hide Releted Team',
        ),
      ),
      array(
        'id'      => 'team_limit',
        'type'    => 'text',
        'title'   => esc_html__('Team Limit For Single Team Page', 'plombiers'),
        'info'   => esc_html__('Enter value in Number, for team single pages Iteam.', 'plombiers'),
        'default' => '4',
      ),
      array(
        'id'      => 'team_order',
        'type'    => 'select',
        'title'   => esc_html__('Team Order for Single Team Page', 'plombiers'),
        'info'   => esc_html__('Select Team order for team single pages.', 'plombiers'),
        'options'   => array(
          'ASC'    => 'Ascending',
          'DESC' => 'Descending ',
        ),
      ),
      // Team End

    ),
  );

  // ------------------------------
  // Blog Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'blog_section',
    'title'    => esc_html__('Blog', 'plombiers'),
    'icon'     => 'fa fa-edit',
    'sections' => array(

      // blog general section
      array(
        'name'     => 'blog_general_tab',
        'title'    => esc_html__('General', 'plombiers'),
        'icon'     => 'fa fa-cog',
        'fields'   => array(

          // Layout
          array(
            'type'    => 'notice',
            'class'   => 'info cs-plombiers-heading',
            'content' => esc_html__('Layout', 'plombiers')
          ),
          array(
            'id'             => 'blog_listing_style',
            'type'           => 'select',
            'title'          => esc_html__('Blog Listing Style','plombiers'),
            'options'        => array(
              'classic' => esc_html__('Classic (Default)', 'plombiers'),
              'grid' => esc_html__('Grid ','plombiers'),
            ),
            'default_option' => 'Select blog style',
            'help'          => esc_html__('This style will apply, default blog pages - Like : Archive, Category, Tags, Search & Author. If this settings will not apply your blog page, please set that page as a post page in Settings > Readings.', 'plombiers'),
          ),
          array(
            'id'             => 'blog_listing_columns',
            'type'           => 'select',
            'title'          => esc_html__('Blog Listing Columns', 'plombiers'),
            'options'        => array(
              'blog-col-1' => esc_html__('Column One', 'plombiers'),
              'blog-col-2' => esc_html__('Column Two', 'plombiers'),
              'blog-col-3' => esc_html__('Column Three', 'plombiers'),
              'blog-col-4' => esc_html__('Column Four', 'plombiers'),
            ),
            'default_option' => 'Select blog column',
            'dependency'     => array('blog_listing_style', '==', 'grid'),
          ),
          array(
            'id'             => 'blog_sidebar_position',
            'type'           => 'select',
            'title'          => esc_html__('Sidebar Position', 'plombiers'),
            'options'        => array(
              'sidebar-right' => esc_html__('Right', 'plombiers'),
              'sidebar-left' => esc_html__('Left', 'plombiers'),
              'sidebar-hide' => esc_html__('Hide', 'plombiers'),
            ),
            'default_option' => 'Select sidebar position',
            'help'          => esc_html__('This style will apply, default blog pages - Like : Archive, Category, Tags, Search & Author.', 'plombiers'),
            'info'          => esc_html__('Default option : Right', 'plombiers'),
          ),
          array(
            'id'             => 'blog_widget',
            'type'           => 'select',
            'title'          => esc_html__('Sidebar Widget', 'plombiers'),
            'options'        => plombiers_registered_sidebars(),
            'default_option' => esc_html__('Select Widget', 'plombiers'),
            'dependency'     => array('blog_sidebar_position', '!=', 'sidebar-hide'),
            'info'          => esc_html__('Default option : Main Widget Area', 'plombiers'),
          ),
          // Layout
          // Global Options
          array(
            'type'    => 'notice',
            'class'   => 'info cs-plombiers-heading',
            'content' => esc_html__('Global Options', 'plombiers')
          ),
          array(
            'id'         => 'theme_exclude_categories',
            'type'       => 'checkbox',
            'title'      => esc_html__('Exclude Categories', 'plombiers'),
            'info'      => esc_html__('Select categories you want to exclude from blog page.', 'plombiers'),
            'options'    => 'categories',
          ),
          array(
            'id'      => 'theme_blog_excerpt',
            'type'    => 'text',
            'title'   => esc_html__('Excerpt Length', 'plombiers'),
            'info'   => esc_html__('Blog short content length, in blog listing pages.', 'plombiers'),
            'default' => '55',
          ),
          array(
            'id'      => 'theme_metas_hide',
            'type'    => 'checkbox',
            'title'   => esc_html__('Meta\'s to hide', 'plombiers'),
            'info'    => esc_html__('Check items you want to hide from blog/post meta field.', 'plombiers'),
            'class'      => 'horizontal',
            'options'    => array(
              'category'   => esc_html__('Category', 'plombiers'),
              'date'    => esc_html__('Date', 'plombiers'),
              'author'     => esc_html__('Author', 'plombiers'),
              'comments'      => esc_html__('Comments', 'plombiers'),
            ),
            // 'default' => '30',
          ),
          // End fields

        )
      ),

      // blog single section
      array(
        'name'     => 'blog_single_tab',
        'title'    => esc_html__('Single', 'plombiers'),
        'icon'     => 'fa fa-sticky-note',
        'fields'   => array(

          // Start fields
          array(
            'type'    => 'notice',
            'class'   => 'info cs-plombiers-heading',
            'content' => esc_html__('Enable / Disable', 'plombiers')
          ),
          array(
            'id'    => 'team_featured_image',
            'type'  => 'switcher',
            'title' => esc_html__('Hide Featured Image?', 'plombiers'),
            'info' => esc_html__('If need to show featured image from single blog post page, please turn this OFF.', 'plombiers'),
            'default' => false,
          ),
          array(
            'id'    => 'single_author_info',
            'type'  => 'switcher',
            'title' => esc_html__('Author Info', 'plombiers'),
            'info' => esc_html__('If need to hide author info on single blog page, please turn this OFF.', 'plombiers'),
            'default' => true,
          ),
          array(
            'id'    => 'single_share_option',
            'type'  => 'switcher',
            'title' => esc_html__('Share Option', 'plombiers'),
            'info' => esc_html__('If need to hide share option on single blog page, please turn this OFF.', 'plombiers'),
            'default' => true,
          ),
          array(
            'id'    => 'single_tags_option',
            'type'  => 'switcher',
            'title' => esc_html__('Hide Tags?', 'plombiers'),
            'info' => esc_html__('If need to hide tags on single blog page, please turn this On.', 'plombiers'),
            'default' => false,
          ),
          array(
            'id'    => 'single_post_pagination',
            'type'  => 'switcher',
            'title' => esc_html__('Hide Single Pagination?', 'plombiers'),
            'info' => esc_html__('If need to hide Single Pagination on single blog page, please turn this On.', 'plombiers'),
            'default' => false,
          ),
          array(
            'id'    => 'single_comment_form',
            'type'  => 'switcher',
            'title' => esc_html__('Hide Comment Area/Form?', 'plombiers'),
            'info' => esc_html__('If need to hide comment area and that form on single blog page, please turn this On.', 'plombiers'),
            'default' => false,
          ),

          array(
            'type'    => 'notice',
            'class'   => 'info cs-plombiers-heading',
            'content' => esc_html__('Sidebar', 'plombiers')
          ),
          array(
            'id'             => 'single_sidebar_position',
            'type'           => 'select',
            'title'          => esc_html__('Sidebar Position', 'plombiers'),
            'options'        => array(
              'sidebar-right' => esc_html__('Right', 'plombiers'),
              'sidebar-left' => esc_html__('Left', 'plombiers'),
              'sidebar-hide' => esc_html__('Hide', 'plombiers'),
            ),
            'default_option' => 'Select sidebar position',
            'info'          => esc_html__('Default option : Right', 'plombiers'),
          ),
          array(
            'id'             => 'single_blog_widget',
            'type'           => 'select',
            'title'          => esc_html__('Sidebar Widget', 'plombiers'),
            'options'        => plombiers_registered_sidebars(),
            'default_option' => esc_html__('Select Widget', 'plombiers'),
            'dependency'     => array('single_sidebar_position', '!=', 'sidebar-hide'),
            'info'          => esc_html__('Default option : Main Widget Area', 'plombiers'),
          ),
          // End fields

        )
      ),

    ),
  );


if (class_exists( 'WooCommerce' )){
  // ------------------------------
  // WooCommerce Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'woocommerce_section',
    'title'    => esc_html__('WooCommerce', 'plombiers'),
    'icon'     => 'fa fa-shopping-cart',
    'fields' => array(

      // Start fields
      array(
        'type'    => 'notice',
        'class'   => 'info cs-plombiers-heading',
        'content' => esc_html__('Layout', 'plombiers')
      ),
      array(
        'id'             => 'woo_product_columns',
        'type'           => 'select',
        'title'          => esc_html__('Product Column', 'plombiers'),
        'options'        => array(
          5 => esc_html__('Five Column', 'plombiers'),
          4 => esc_html__('Four Column', 'plombiers'),
          3 => esc_html__('Three Column', 'plombiers'),
          2 => esc_html__('Two Column', 'plombiers'),

        ),
        'default_option' => esc_html__('Select Product Columns', 'plombiers'),
        'help'          => esc_html__('This style will apply, default woocommerce listings pages. Like, shop and archive pages.', 'plombiers'),
      ),
      array(
        'id'             => 'woo_sidebar_position',
        'type'           => 'select',
        'title'          => esc_html__('Sidebar Position', 'plombiers'),
        'options'        => array(
          'right-sidebar' => esc_html__('Right', 'plombiers'),
          'left-sidebar' => esc_html__('Left', 'plombiers'),
          'sidebar-hide' => esc_html__('Hide', 'plombiers'),
        ),
        'default_option' => esc_html__('Select sidebar position', 'plombiers'),
        'info'          => esc_html__('Default option : Right', 'plombiers'),
      ),
      array(
        'id'             => 'woo_widget',
        'type'           => 'select',
        'title'          => esc_html__('Sidebar Widget', 'plombiers'),
        'options'        => plombiers_registered_sidebars(),
        'default_option' => esc_html__('Select Widget', 'plombiers'),
        'dependency'     => array('woo_sidebar_position', '!=', 'sidebar-hide'),
        'info'          => esc_html__('Default option : Shop Page', 'plombiers'),
      ),

      array(
        'type'    => 'notice',
        'class'   => 'info cs-plombiers-heading',
        'content' => esc_html__('Listing', 'plombiers')
      ),
      array(
        'id'      => 'plombiers_woo_limit',
        'type'    => 'text',
        'title'   => esc_html__('Product Limit', 'plombiers'),
        'info'   => esc_html__('Enter the number value for per page products limit.', 'plombiers'),
      ),

      // End fields

      // Start fields
      array(
        'type'    => 'notice',
        'class'   => 'info cs-plombiers-heading',
        'content' => esc_html__('Single Product', 'plombiers')
      ),
      array(
        'id'    => 'plombiers_woo_single_upsell',
        'type'  => 'switcher',
        'title' => esc_html__('You May Also Like', 'plombiers'),
        'info' => esc_html__('If you don\'t want \'You May Also Like\' products in single product page, please turn this ON.', 'plombiers'),
        'default' => false,
      ),
      array(
        'id'    => 'plombiers_woo_single_related',
        'type'  => 'switcher',
        'title' => esc_html__('Related Products', 'plombiers'),
        'info' => esc_html__('If you don\'t want \'Related Products\' in single product page, please turn this ON.', 'plombiers'),
        'default' => false,
      ),
      array(
        'id'             => 'woo_related_limit',
        'type'           => 'text',
        'title'          => esc_html__('Related Products Limit', 'plombiers'),
     'dependency'     => array('plombiers_woo_single_related', '==' , false),
      ),
      // End fields

    ),
  );
}

$cf7 = get_posts( 'post_type="wpcf7_contact_form"&numberposts=-1' );
    $contact_forms = array();
    if ( $cf7 ) {
      foreach ( $cf7 as $cform ) {
        $contact_forms[ $cform->ID ] = $cform->post_title ;
      }
    } else {
      $contact_forms[ esc_html__( 'No contact forms found', 'plombiers' ) ] = 0;
    }
  // ------------------------------
  // Extra Pages
  // ------------------------------
  $options[]   = array(
    'name'     => 'theme_extra_pages',
    'title'    => esc_html__('Extra Pages', 'plombiers'),
    'icon'     => 'fa fa-clone',
    'sections' => array(

      // error 404 page
      array(
        'name'     => 'error_page_section',
        'title'    => esc_html__('404 Page', 'plombiers'),
        'icon'     => 'fa fa-exclamation-triangle',
        'fields'   => array(

          // Start 404 Page
          array(
            'id'    => 'error_heading',
            'type'  => 'text',
            'title' => esc_html__('404 Page Heading', 'plombiers'),
            'info'  => esc_html__('Enter 404 page heading.', 'plombiers'),
          ),
          array(
            'id'    => 'error_subheading',
            'type'  => 'text',
            'title' => esc_html__('404 Page Sub Heading', 'plombiers'),
            'info'  => esc_html__('Enter 404 Sub page heading.', 'plombiers'),
          ),
          array(
            'id'    => 'error_page_content',
            'type'  => 'textarea',
            'title' => esc_html__('404 Page Content', 'plombiers'),
            'info'  => esc_html__('Enter 404 page content.', 'plombiers'),
            'shortcode' => true,
          ),
          array(
            'id'    => 'error_page_bg',
            'type'  => 'image',
            'title' => esc_html__('404 Page Background', 'plombiers'),
            'info'  => esc_html__('Choose 404 page background styles.', 'plombiers'),
            'add_title' => esc_html__('Add 404 Image', 'plombiers'),
          ),
          array(
            'id'    => 'error_btn_text',
            'type'  => 'text',
            'title' => esc_html__('Button Text', 'plombiers'),
            'info'  => esc_html__('Enter BACK TO HOME button text. If you want to change it.', 'plombiers'),
          ),
          // End 404 Page

        ) // end: fields
      ), // end: fields section
      // maintenance mode page
      array(
        'name'     => 'maintenance_mode_section',
        'title'    => esc_html__('Maintenance Mode', 'plombiers'),
        'icon'     => 'fa fa-hourglass-half',
        'fields'   => array(

          // Start Maintenance Mode
          array(
            'type'    => 'notice',
            'class'   => 'info cs-plombiers-heading',
            'content' => esc_html__('If you turn this ON : Only Logged in users will see your pages. All other visiters will see, selected page of : <strong>Maintenance Mode Page</strong>', 'plombiers')
          ),
          array(
            'id'             => 'enable_maintenance_mode',
            'type'           => 'switcher',
            'title'          => esc_html__('Maintenance Mode', 'plombiers'),
            'default'        => false,
          ),
          array(
            'id'             => 'maintenance_mode_page',
            'type'           => 'select',
            'title'          => esc_html__('Maintenance Mode Page', 'plombiers'),
            'options'        => 'pages',
            'default_option' => esc_html__('Select a page', 'plombiers'),
            'dependency'   => array( 'enable_maintenance_mode', '==', 'true' ),
          ),
          array(
            'id'             => 'maintenance_mode_bg',
            'type'           => 'background',
            'title'          => esc_html__('Page Background', 'plombiers'),
            'dependency'   => array( 'enable_maintenance_mode', '==', 'true' ),
          ),
          array(
            'id'             => 'maintenance_man',
            'type'           => 'image',
            'title'          => esc_html__('Page Background', 'plombiers'),
            'dependency'   => array( 'enable_maintenance_mode', '==', 'true' ),
          ),
          array(
            'id'             => 'maintenance_mode_text',
            'type'           => 'textarea',
            'title'          => esc_html__('Maintenance Mode Text', 'plombiers'),
            'dependency'   => array( 'enable_maintenance_mode', '==', 'true' ),
          ),
          array(
            'id'             => 'maintenance_mode_form',
            'type'           => 'select',
            'title'          => esc_html__('Maintenance Mode Form', 'plombiers'),
            'options'        => $contact_forms,
            'dependency'   => array( 'enable_maintenance_mode', '==', 'true' ),
          ),
          // End Maintenance Mode

        ) // end: fields
      ), // end: fields section

    )
  );

  // ------------------------------
  // Advanced
  // ------------------------------
  $options[] = array(
    'name'   => 'theme_advanced',
    'title'  => esc_html__('Advanced', 'plombiers'),
    'icon'   => 'fa fa-cog'
  );

  // ------------------------------
  // Misc Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'misc_section',
    'title'    => esc_html__('Misc', 'plombiers'),
    'icon'     => 'fa fa-recycle',
    'sections' => array(

      // custom sidebar section
      array(
        'name'     => 'custom_sidebar_section',
        'title'    => esc_html__('Custom Sidebar', 'plombiers'),
        'icon'     => 'fa fa-reorder',
        'fields'   => array(

          // start fields
          array(
            'id'              => 'custom_sidebar',
            'title'           => esc_html__('Sidebars', 'plombiers'),
            'desc'            => esc_html__('Go to Appearance -> Widgets after create sidebars', 'plombiers'),
            'type'            => 'group',
            'fields'          => array(
              array(
                'id'          => 'sidebar_name',
                'type'        => 'text',
                'title'       => esc_html__('Sidebar Name', 'plombiers'),
              ),
              array(
                'id'          => 'sidebar_desc',
                'type'        => 'text',
                'title'       => esc_html__('Custom Description', 'plombiers'),
              )
            ),
            'accordion'       => true,
            'button_title'    => esc_html__('Add New Sidebar', 'plombiers'),
            'accordion_title' => esc_html__('New Sidebar', 'plombiers'),
          ),
          // end fields

        )
      ),
      // custom sidebar section

      // Custom CSS/JS
      array(
        'name'        => 'custom_css_js_section',
        'title'       => esc_html__('Custom Codes', 'plombiers'),
        'icon'        => 'fa fa-code',

        // begin: fields
        'fields'      => array(
          array(
            'type'    => 'notice',
            'class'   => 'info cs-plombiers-heading',
            'content' => esc_html__('Custom JS', 'plombiers')
          ),
          array(
            'id'             => 'theme_custom_js',
            'type'           => 'textarea',
            'attributes' => array(
              'rows'     => 10,
              'placeholder'     => esc_html__('Enter your JS code here...', 'plombiers'),
            ),
          ),
          // End Custom CSS/JS

        ) // end: fields
      ),

      // Translation
      array(
        'name'        => 'theme_translation_section',
        'title'       => esc_html__('Translation', 'plombiers'),
        'icon'        => 'fa fa-language',

        // begin: fields
        'fields'      => array(

          // Start Translation
          array(
            'type'    => 'notice',
            'class'   => 'info cs-plombiers-heading',
            'content' => esc_html__('Common Texts', 'plombiers')
          ),
          array(
            'id'          => 'read_more_text',
            'type'        => 'text',
            'title'       => esc_html__('Read More Text', 'plombiers'),
          ),
          array(
            'id'          => 'view_more_text',
            'type'        => 'text',
            'title'       => esc_html__('View More Text', 'plombiers'),
          ),
          array(
            'id'          => 'share_text',
            'type'        => 'text',
            'title'       => esc_html__('Share Text', 'plombiers'),
          ),
          array(
            'id'          => 'share_on_text',
            'type'        => 'text',
            'title'       => esc_html__('Share On Tooltip Text', 'plombiers'),
          ),
          array(
            'id'          => 'author_text',
            'type'        => 'text',
            'title'       => esc_html__('Author Text', 'plombiers'),
          ),
          array(
            'id'          => 'post_comment_text',
            'type'        => 'text',
            'title'       => esc_html__('Post Comment Text [Submit Button]', 'plombiers'),
          ),
          array(
            'type'    => 'notice',
            'class'   => 'info cs-plombiers-heading',
            'content' => esc_html__('WooCommerce', 'plombiers')
          ),
          array(
            'id'          => 'add_to_cart_text',
            'type'        => 'text',
            'title'       => esc_html__('Add to Cart Text', 'plombiers'),
          ),
          array(
            'id'          => 'details_text',
            'type'        => 'text',
            'title'       => esc_html__('Details Text', 'plombiers'),
          ),

          array(
            'type'    => 'notice',
            'class'   => 'info cs-plombiers-heading',
            'content' => esc_html__('Pagination', 'plombiers')
          ),
          array(
            'id'          => 'older_post',
            'type'        => 'text',
            'title'       => esc_html__('Older Posts Text', 'plombiers'),
          ),
          array(
            'id'          => 'newer_post',
            'type'        => 'text',
            'title'       => esc_html__('Newer Posts Text', 'plombiers'),
          ),

          array(
            'type'    => 'notice',
            'class'   => 'info cs-plombiers-heading',
            'content' => esc_html__('Single Portfolio Pagination', 'plombiers')
          ),
          array(
            'id'          => 'prev_port',
            'type'        => 'text',
            'title'       => esc_html__('Prev Project Text', 'plombiers'),
          ),
          array(
            'id'          => 'next_port',
            'type'        => 'text',
            'title'       => esc_html__('Next Project Text', 'plombiers'),
          ),
          // End Translation

        ) // end: fields
      ),

    ),
  );

  // ------------------------------
  // envato account
  // ------------------------------
  $options[]   = array(
    'name'     => 'envato_account_section',
    'title'    => esc_html__('Envato Account', 'plombiers'),
    'icon'     => 'fa fa-link',
    'fields'   => array(

      array(
        'type'    => 'notice',
        'class'   => 'warning',
        'content' => esc_html__('Enter your Username and API key. You can get update our themes from WordPress admin itself.', 'plombiers'),
      ),
      array(
        'id'      => 'themeforest_username',
        'type'    => 'text',
        'title'   => esc_html__('Envato Username', 'plombiers'),
      ),
      array(
        'id'      => 'themeforest_api',
        'type'    => 'text',
        'title'   => esc_html__('Envato API Key', 'plombiers'),
        'class'   => 'text-security',
        'after'   => wp_kses( __('<p>This is not a password field. Enter your Envato API key, which is located in : <strong>http://themeforest.net/user/[YOUR-USER-NAME]/api_keys/edit</strong></p>', 'plombiers'), array( 'p' => array(), 'strong' => array() ) ),
      ),
    )
  );

  // ------------------------------
  // backup                       -
  // ------------------------------
  $options[]   = array(
    'name'     => 'backup_section',
    'title'    => 'Backup',
    'icon'     => 'fa fa-shield',
    'fields'   => array(

      array(
        'type'    => 'notice',
        'class'   => 'warning',
        'content' => esc_html__('You can save your current options. Download a Backup and Import.', 'plombiers'),
      ),

      array(
        'type'    => 'backup',
      ),

    )
  );

  return $options;

}
add_filter( 'cs_framework_options', 'plombiers_options' );