<?php
/*
 * All theme related setups here.
 * Author & Copyright: IRSFoundation
 * URL: http://themeforest.net/user/irsfoundation
 */

/* Set content width */
if ( ! isset( $content_width ) ) $content_width = 1170;

/* Register menu */
register_nav_menus( array(
	'primary' => esc_html__( 'Main Navigation', 'plombiers' )
) );

/* Thumbnails */
add_theme_support( 'post-thumbnails' );

/* Post formats */
add_theme_support( 'post-formats', array( 'gallery', 'image' , 'audio', 'video') );

/* Feeds */
add_theme_support( 'automatic-feed-links' );

/* Add support for Title Tag. */
add_theme_support( 'title-tag' );

/* HTML5 */
add_theme_support( 'html5', array( 'gallery', 'caption' ) );

/* Breadcrumb Trail Support */
add_theme_support( 'breadcrumb-trail' );

if (class_exists('WooCommerce')) {
	add_theme_support( 'woocommerce' );
}

/* Extend wp_title */
if( ! function_exists( 'plombiers_theme_wp_title' ) ) {
	function plombiers_theme_wp_title( $title, $sep ) {
	 global $paged, $page;

	 if ( is_feed() )
	  return $title;

	 // Add the site name.
	 $site_name = get_bloginfo( 'name' );

	 // Add the site description for the home/front page.
	 $site_description = get_bloginfo( 'description', 'display' );
	 if ( $site_description && ( is_front_page() ) )
	  $title = "$site_name $sep $site_description";

	 // Add a page number if necessary.
	 if ( $paged >= 2 || $page >= 2 )
	  $title = "$site_name $sep" . sprintf( esc_html__( ' Page %s', 'plombiers' ), max( $paged, $page ) );

	 return $title;
	}
	add_filter( 'wp_title', 'plombiers_theme_wp_title', 10, 2 );
}

/* Languages */
if( ! function_exists( 'plombiers_theme_language_setup' ) ) {
	function plombiers_theme_language_setup(){
	  load_theme_textdomain( 'plombiers', get_template_directory() . '/languages' );
	  add_editor_style();
	}
	add_action('after_setup_theme', 'plombiers_theme_language_setup');
}

/* Slider Revolution Theme Mode */
if(function_exists( 'set_revslider_as_theme' )){
	add_action( 'init', 'plombiers_theme_revslider' );
	function plombiers_theme_revslider() {
		set_revslider_as_theme();
	}
}

/* Visual Composer Theme Mode */
if(function_exists('vc_set_as_theme')) vc_set_as_theme();

remove_action( 'woocommerce_before_main_content','woocommerce_breadcrumb', 20, 0);
add_filter('woocommerce_show_page_title', '__return_false');

/**
 * Products per page.
 *
 * @return integer number of products.
 */
function plombiers_woocommerce_products_per_page() {
	$plombiers_product_count = cs_get_option('plombiers_woo_limit');
	$plombiers_product_count = $plombiers_product_count ? $plombiers_product_count : 8;
	return (int) $plombiers_product_count;
}
add_filter( 'loop_shop_per_page', 'plombiers_woocommerce_products_per_page' );


/**
 * Related Products Args.
 *
 * @param array $args related products args.
 */
function plombiers_woocommerce_related_products_args( $args ) {
	$plombiers_releted_count = cs_get_option('woo_related_limit');
	$defaults = array(
		'posts_per_page' => $plombiers_releted_count,
	);
	$args = wp_parse_args( $defaults, $args );
	return $args;
}
add_filter( 'woocommerce_output_related_products_args', 'plombiers_woocommerce_related_products_args' );


function plombiers_wc_remove_related_products()  {
	$plombiers_woo_single_related = cs_get_option('plombiers_woo_single_related');
	$plombiers_woo_single_upsell = cs_get_option('plombiers_woo_single_upsell');
  if ( $plombiers_woo_single_related == true ) {
     return remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20 );
	}
  if ( $plombiers_woo_single_upsell == true ) {
     return remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15 );
	}
}
add_action('after_setup_theme','plombiers_wc_remove_related_products', 10);

add_filter('loop_shop_columns', 'loop_columns');
if (!function_exists('loop_columns')) {
	function loop_columns() {
	$plombiers_woo_product_columns = cs_get_option('woo_product_columns');
	$plombiers_woo_product_columns = $plombiers_woo_product_columns ? $plombiers_woo_product_columns : 4;
		return (int) $plombiers_woo_product_columns; // 3 products per row
	}
}


