<?php
/*
 * Recent Post Widget
 * Author & Copyright: Edge Theme
 * URL: http://themeforest.net/user/edge_theme
 */

class plombiers_recent_posts extends WP_Widget {

  /**
   * Specifies the widget name, description, class name and instatiates it
   */
  public function __construct() {
    parent::__construct(
      '-recent-blog',
      PLOMBIERS_THEME_NAME_PLUGIN . esc_html__( ': Recent Posts', 'plombiers-core' ),
      array(
        'classname'   => 'recent-blog',
        'description' => PLOMBIERS_THEME_NAME_PLUGIN . esc_html__( ' widget that displays recent posts.', 'plombiers-core' )
      )
    );
  }

  /**
   * Generates the back-end layout for the widget
   */
  public function form( $instance ) {
    // Default Values
    $instance   = wp_parse_args( $instance, array(
      'title'    => esc_html__( 'Recent Posts', 'plombiers-core' ),
      'ptypes'   => 'post',
      'limit'    => '3',
      'date'     => true,
      'category' => '',
      'order' => '',
      'orderby' => '',
    ));

    // Title
    $title_value = esc_attr( $instance['title'] );
    $title_field = array(
      'id'    => $this->get_field_name('title'),
      'name'  => $this->get_field_name('title'),
      'type'  => 'text',
      'title' => esc_html__( 'Title :', 'plombiers-core' ),
      'wrap_class' => 'cs-widget-fields',
    );
    echo cs_add_element( $title_field, $title_value );

    // Post Type
    $ptypes_value = esc_attr( $instance['ptypes'] );
    $ptypes_field = array(
      'id'    => $this->get_field_name('ptypes'),
      'name'  => $this->get_field_name('ptypes'),
      'type' => 'select',
      'options' => 'post_types',
      'default_option' => esc_html__( 'Select Post Type', 'plombiers-core' ),
      'title' => esc_html__( 'Post Type :', 'plombiers-core' ),
    );
    echo cs_add_element( $ptypes_field, $ptypes_value );

    // Limit
    $limit_value = esc_attr( $instance['limit'] );
    $limit_field = array(
      'id'    => $this->get_field_name('limit'),
      'name'  => $this->get_field_name('limit'),
      'type'  => 'text',
      'title' => esc_html__( 'Limit :', 'plombiers-core' ),
      'help' => esc_html__( 'How many posts want to show?', 'plombiers-core' ),
    );
    echo cs_add_element( $limit_field, $limit_value );

    // Date
    $date_value = esc_attr( $instance['date'] );
    $date_field = array(
      'id'    => $this->get_field_name('date'),
      'name'  => $this->get_field_name('date'),
      'type'  => 'switcher',
      'on_text'  => esc_html__( 'Yes', 'plombiers-core' ),
      'off_text'  => esc_html__( 'No', 'plombiers-core' ),
      'title' => esc_html__( 'Display Date :', 'plombiers-core' ),
    );
    echo cs_add_element( $date_field, $date_value );

    // Category
    $category_value = esc_attr( $instance['category'] );
    $category_field = array(
      'id'    => $this->get_field_name('category'),
      'name'  => $this->get_field_name('category'),
      'type'  => 'text',
      'title' => esc_html__( 'Category :', 'plombiers-core' ),
      'help' => esc_html__( 'Enter category slugs with comma(,) for multiple items', 'plombiers-core' ),
    );
    echo cs_add_element( $category_field, $category_value );

    // Order
    $order_value = esc_attr( $instance['order'] );
    $order_field = array(
      'id'    => $this->get_field_name('order'),
      'name'  => $this->get_field_name('order'),
      'type' => 'select',
      'options'   => array(
        'ASC' => 'Ascending',
        'DESC' => 'Descending',
      ),
      'default_option' => esc_html__( 'Select Order', 'plombiers-core' ),
      'title' => esc_html__( 'Order :', 'plombiers-core' ),
    );
    echo cs_add_element( $order_field, $order_value );

    // Orderby
    $orderby_value = esc_attr( $instance['orderby'] );
    $orderby_field = array(
      'id'    => $this->get_field_name('orderby'),
      'name'  => $this->get_field_name('orderby'),
      'type' => 'select',
      'options'   => array(
        'none' => esc_html__('None', 'plombiers-core'),
        'ID' => esc_html__('ID', 'plombiers-core'),
        'author' => esc_html__('Author', 'plombiers-core'),
        'title' => esc_html__('Title', 'plombiers-core'),
        'name' => esc_html__('Name', 'plombiers-core'),
        'type' => esc_html__('Type', 'plombiers-core'),
        'date' => esc_html__('Date', 'plombiers-core'),
        'modified' => esc_html__('Modified', 'plombiers-core'),
        'rand' => esc_html__('Random', 'plombiers-core'),
      ),
      'default_option' => esc_html__( 'Select OrderBy', 'plombiers-core' ),
      'title' => esc_html__( 'OrderBy :', 'plombiers-core' ),
    );
    echo cs_add_element( $orderby_field, $orderby_value );

  }

  /**
   * Processes the widget's values
   */
  public function update( $new_instance, $old_instance ) {
    $instance = $old_instance;

    // Update values
    $instance['title']        = strip_tags( stripslashes( $new_instance['title'] ) );
    $instance['ptypes']       = strip_tags( stripslashes( $new_instance['ptypes'] ) );
    $instance['limit']        = strip_tags( stripslashes( $new_instance['limit'] ) );
    $instance['date']         = strip_tags( stripslashes( $new_instance['date'] ) );
    $instance['category']     = strip_tags( stripslashes( $new_instance['category'] ) );
    $instance['order']        = strip_tags( stripslashes( $new_instance['order'] ) );
    $instance['orderby']      = strip_tags( stripslashes( $new_instance['orderby'] ) );

    return $instance;
  }

  /**
   * Output the contents of the widget
   */
  public function widget( $args, $instance ) {
    // Extract the arguments
    extract( $args );

    $title          = apply_filters( 'widget_title', $instance['title'] );
    $ptypes         = $instance['ptypes'];
    $limit          = $instance['limit'];
    $display_date   = $instance['date'];
    $category       = $instance['category'];
    $order          = $instance['order'];
    $orderby        = $instance['orderby'];

    $args = array(
      // other query params here,
      'post_type' => esc_attr($ptypes),
      'posts_per_page' => (int)$limit,
      'orderby' => esc_attr($orderby),
      'order' => esc_attr($order),
      'category_name' => esc_attr($category),
      'ignore_sticky_posts' => 1,
     );

     $plombiers_rpw = new WP_Query( $args );
     global $post;

    // Display the markup before the widget
    echo $before_widget;

    if ( $title ) {
      echo $before_title . $title . $after_title;
    }

    echo '<div class="media">';

    if ($plombiers_rpw->have_posts()) : while ($plombiers_rpw->have_posts()) : $plombiers_rpw->the_post();
      $large_image =  wp_get_attachment_image_src( get_post_thumbnail_id(get_the_ID()), 'fullsize', false, '' );
      $large_image = $large_image[0];
      if(class_exists('Aq_Resize')) {
        $post_img = aq_resize( $large_image, '70', '70', true );
      } else {
         $post_img = $large_image;
      }
      if (!empty( $post_img )) {
        $post_img = $post_img;
      } else {
        $post_img = PLOMBIERS_PLUGIN_IMGS.'/70X80.jpg';
      } ?>
    <div class="plmbr-recent-widget clearfix">
      <div class="media-left pull-left ">
          <a href="<?php esc_url(the_permalink()) ?>">
              <img class="media-object" src="<?php echo esc_url(  $post_img ); ?>" alt="newss1.jpg">
          </a>
      </div>
      <div class="media-body">
          <h5 class="media-heading"><?php the_title(); ?></h5>
          <?php if ($display_date === '1') { ?>
          <h6 class="plmbr-bsmp-ttl"><?php echo get_the_date('M j, Y'); ?></h6>
           <?php } ?>
          <a class="plmbr-bsmpa" href="<?php esc_url(the_permalink()) ?>">Read More</a>
      </div>
    </div>
  <?php
    endwhile; endif;
    echo '</div>';
    wp_reset_postdata();
    // Display the markup after the widget
    echo $after_widget;
  }
}

// Register the widget using an annonymous function
add_action( 'widgets_init', create_function( '', 'register_widget( "plombiers_recent_posts" );' ) );