<?php
/*
 * All Front-End Helper Functions
 * Author & Copyright: IRSFoundation
 * URL: http://themeforest.net/user/irsfoundation
 */

/* Exclude category from blog */
if( ! function_exists( 'plombiers_excludeCat' ) ) {
  function plombiers_excludeCat($query) {
  	if ( $query->is_home ) {
  		$exclude_cat_ids = cs_get_option('theme_exclude_categories');
  		if($exclude_cat_ids) {
  			foreach( $exclude_cat_ids as $exclude_cat_id ) {
  				$exclude_from_blog[] = '-'. $exclude_cat_id;
  			}
  			$query->set('cat', implode(',', $exclude_from_blog));
  		}
  	}
  	return $query;
  }
  add_filter('pre_get_posts', 'plombiers_excludeCat');
}

/* Excerpt Length */
class PlombiersExcerpt {

  // Default length (by WordPress)
  public static $length = 55;

  // Output: plombiers_excerpt('short');
  public static $types = array(
    'short' => 25,
    'regular' => 55,
    'long' => 100
  );

  /**
   * Sets the length for the excerpt,
   * then it adds the WP filter
   * And automatically calls the_excerpt();
   *
   * @param string $new_length
   * @return void
   * @author Baylor Rae'
   */
  public static function length($new_length = 55) {
    PlombiersExcerpt::$length = $new_length;
    add_filter('excerpt_length', 'PlombiersExcerpt::new_length');
    PlombiersExcerpt::output();
  }

  // Tells WP the new length
  public static function new_length() {
    if( isset(PlombiersExcerpt::$types[PlombiersExcerpt::$length]) )
      return PlombiersExcerpt::$types[PlombiersExcerpt::$length];
    else
      return PlombiersExcerpt::$length;
  }

  // Echoes out the excerpt
  public static function output() {
    the_excerpt();
  }

}

// Custom Excerpt Length
if( ! function_exists( 'plombiers_excerpt' ) ) {
  function plombiers_excerpt($length = 55) {
    PlombiersExcerpt::length($length);
  }
}

if ( ! function_exists( 'plombiers_new_excerpt_more' ) ) {
  function plombiers_new_excerpt_more( $more ) {
    return ' ';
  }
  add_filter('excerpt_more', 'plombiers_new_excerpt_more');
}

/* Tag Cloud Widget - Remove Inline Font Size */
if( ! function_exists( 'plombiers_tag_cloud' ) ) {
  function plombiers_tag_cloud($tag_string){
    return preg_replace("/style='font-size:.+pt;'/", '', $tag_string);
  }
  add_filter('wp_generate_tag_cloud', 'plombiers_tag_cloud', 10, 3);
}

/* Password Form */
if( ! function_exists( 'plombiers_password_form' ) ) {
  function plombiers_password_form( $output ) {
    $output = str_replace( 'type="submit"', 'type="submit" class=""', $output );
    return $output;
  }
  add_filter('the_password_form' , 'plombiers_password_form');
}

/* Maintenance Mode */
if( ! function_exists( 'plombiers_maintenance_mode' ) ) {
  function plombiers_maintenance_mode(){

    $maintenance_mode_page = cs_get_option( 'maintenance_mode_page' );

    if ( ! empty( $maintenance_mode_page ) && ! is_user_logged_in() ) {
      get_template_part('theme-layouts/post/content', 'maintenance');
      exit;
    }

  }
  add_action( 'wp', 'plombiers_maintenance_mode', 1 );
}

/* Widget Layouts */
if ( ! function_exists( 'plombiers_footer_widgets' ) ) {
  function plombiers_footer_widgets() {

    $output = '';
    $footer_widget_layout = cs_get_option('footer_widget_layout');

    if( $footer_widget_layout ) {

      switch ( $footer_widget_layout ) {
        case 1: $widget = array('piece' => 1, 'class' => 'col-md-12'); break;
        case 2: $widget = array('piece' => 2, 'class' => 'col-md-6'); break;
        case 3: $widget = array('piece' => 3, 'class' => 'col-md-4'); break;
        case 4: $widget = array('piece' => 4, 'class' => 'col-md-3 col-sm-6'); break;
        case 5: $widget = array('piece' => 3, 'class' => 'col-md-3', 'layout' => 'col-md-6', 'queue' => 1); break;
        case 6: $widget = array('piece' => 3, 'class' => 'col-md-3', 'layout' => 'col-md-6', 'queue' => 2); break;
        case 7: $widget = array('piece' => 3, 'class' => 'col-md-3', 'layout' => 'col-md-6', 'queue' => 3); break;
        case 8: $widget = array('piece' => 4, 'class' => 'col-md-2', 'layout' => 'col-md-6', 'queue' => 1); break;
        case 9: $widget = array('piece' => 4, 'class' => 'col-md-2', 'layout' => 'col-md-6', 'queue' => 4); break;
        default : $widget = array('piece' => 4, 'class' => 'col-md-3'); break;
      }

      for( $i = 1; $i < $widget["piece"]+1; $i++ ) {

        $widget_class = ( isset( $widget["queue"] ) && $widget["queue"] == $i ) ? $widget["layout"] : $widget["class"];

        $output .= '<div class="'. $widget_class .'">';
        ob_start();
        if (is_active_sidebar('footer-'. $i)) {
          dynamic_sidebar( 'footer-'. $i );
        }
        $output .= ob_get_clean();
        $output .= '</div>';

      }
    }

    return $output;

  }
}

if( ! function_exists( 'plombiers_top_bar' ) ) {
  function plombiers_top_bar() {

    $out     = '';

    if ( ( cs_get_option( 'top_left' ) || cs_get_option( 'top_right' ) ) ) {
      $out .= '<div class="topbar"><div class="container"><div class="row">';
      $out .= plombiers_top_bar_modules( 'left' );
      $out .= plombiers_top_bar_modules( 'right' );
      $out .= '</div></div></div>';
    }

    return $out;
  }
}

/* WP Link Pages */
if ( ! function_exists( 'plombiers_wp_link_pages' ) ) {
  function plombiers_wp_link_pages() {
    $defaults = array(
      'before'           => '<div class="wp-link-pages">' . esc_html__( 'Pages:', 'plombiers' ),
      'after'            => '</div>',
      'link_before'      => '<span>',
      'link_after'       => '</span>',
      'next_or_number'   => 'number',
      'separator'        => ' ',
      'pagelink'         => '%',
      'echo'             => 1
    );
    wp_link_pages( $defaults );
  }
}

/* Metas */
if ( ! function_exists( 'plombiers_post_metas' ) ) {
  function plombiers_post_metas() {
  $metas_hide = (array) cs_get_option( 'theme_metas_hide' );
  ?>
  <ul class="plmbr-bpstcmnt list-inline">
  <?php
    if ( !in_array( 'author', $metas_hide ) ) { // Author Hide
      ?>
      <li><span class="fa fa-user">
        <?php
        printf(
          '<span>'. esc_html__('by','plombiers') .' <a href="%1$s" rel="author">%2$s</a></span>',
          esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
          get_the_author()
        );
        ?></span>
      </li>
      <?php }
      if ( !in_array( 'category', $metas_hide ) ) { // Category Hide
        if ( get_post_type() === 'post') {
          $category_list = get_the_category_list( '</span></li><li><span class="fa fa-cog"> ' );
          if ( $category_list ) {
            echo '<li><span class="fa fa-cog"> '.$category_list .' </span></li>';
          }
        }
      } // Category Hides

      if ( !in_array( 'date', $metas_hide ) ) { // Date Hide
      ?>
      <li>
        <span class=" fa-calendar-o"> <?php echo get_the_date(); ?></span>
      </li>
      <?php }  ?>
    </ul>
  <?php
  }
}

/* Author Info */
if ( ! function_exists( 'plombiers_author_info' ) ) {
  function plombiers_author_info() {

    if (get_the_author_meta( 'url' )) {
      $author_url = get_author_posts_url( get_the_author_meta( 'ID' ) );
      $website_url = get_the_author_meta( 'url' );
    } else {
      $author_url = get_author_posts_url( get_the_author_meta( 'ID' ) );
      $website_url = get_author_posts_url( get_the_author_meta( 'ID' ) );
    }

    // variables
    $author_text = cs_get_option('author_text');
    $author_text = $author_text ? $author_text : esc_html__( 'Author', 'plombiers' );
    $author_content = get_the_author_meta( 'description' );
if ($author_content) {
?>
  <div class="bp-author-info rounded-three">
    <div class="author-avatar">
      <a href="<?php echo esc_url($website_url); ?>">
        <?php echo get_avatar( get_the_author_meta( 'ID' ), 80 ); ?>
      </a>
    </div>
    <div class="author-content">
      <div class="author-pro"><?php echo esc_attr($author_text); ?></div>
      <a href="<?php echo esc_url($author_url); ?>" class="author-name"><?php echo get_the_author_meta('first_name').' '.get_the_author_meta('last_name'); ?></a>
      <p><?php echo wp_kses_post( get_the_author_meta( 'description' ) ); ?></p>
    </div>
  </div>
<?php
} // if $author_content
  }
}

/* ==============================================
   Custom Comment Area Modification
=============================================== */
if ( ! function_exists( 'plombiers_comment_modification' ) ) {
  function plombiers_comment_modification($comment, $args, $depth) {
    $GLOBALS['comment'] = $comment;
    extract($args, EXTR_SKIP);
    if ( 'div' == $args['style'] ) {
      $tag = 'div';
      $add_below = 'comment';
    } else {
      $tag = 'li';
      $add_below = 'div-comment';
    }
    $comment_class = empty( $args['has_children'] ) ? '' : 'parent';
  ?>

  <<?php echo esc_attr($tag); ?> <?php comment_class('item clearfix comment-li-wrap ' . $comment_class .' ' ); ?> id="comment-<?php comment_ID() ?>">
    <?php if ( 'div' != $args['style'] ) : ?>
    <div id="div-comment-<?php comment_ID() ?>" class="">
    <?php endif; ?>
    <div class="comment-theme">
        <div class="comment-image">
          <?php if ( $args['avatar_size'] != 0 ) {
            echo get_avatar( $comment, 80 );
          } ?>
        </div>
    </div>
    <div class="comment-main-area">
      <div class="comments-meta">
        <h4><?php printf( '%s', get_comment_author() ); ?> </h4>
        <span class="comments-date">
          <?php echo get_comment_date('F j, Y'); echo ' - '; ?>
          <span class="caps">AT <?php echo get_comment_time(); ?></span>
        </span>
        <div class="comments-reply">
        <?php
          comment_reply_link( array_merge( $args, array(
          'reply_text' => '<span class="comment-reply-link">'. esc_html__('Reply','plombiers') .'</span>',
          'before' => '',
          'class'  => '',
          'depth' => $depth,
          'max_depth' => $args['max_depth']
          ) ) );
        ?>
        </div>
      </div>
      <?php if ( $comment->comment_approved == '0' ) : ?>
      <em class="comment-awaiting-moderation"><?php echo esc_html__( 'Your comment is awaiting moderation.', 'plombiers' ); ?></em>
      <?php endif; ?>
      <div class="comment-area">
        <?php comment_text(); ?>
      </div>
    </div>
  <?php if ( 'div' != $args['style'] ) : ?>
  </div>
  <?php endif;
  }
}

/* Comments Form - Textarea next to Normal Fields */
if( ! function_exists( 'plombiers_move_comment_field' ) ) {
  add_filter( 'comment_form_fields', 'plombiers_move_comment_field' );
  function plombiers_move_comment_field( $fields ) {
    $comment_field = $fields['comment'];
    unset( $fields['comment'] );
    $fields['comment'] = $comment_field;
    return $fields;
  }
}

/* Title Area */
if ( ! function_exists( 'plombiers_title_area' ) ) {
  function plombiers_title_area() {

    global $post, $wp_query;

    // Get post meta in all type of WP pages
    $plombiers_id    = ( isset( $post ) ) ? $post->ID : 0;
    $plombiers_id    = ( is_home() ) ? get_option( 'page_for_posts' ) : $plombiers_id;
    $plombiers_id    = ( is_woocommerce_shop() ) ? wc_get_page_id( 'shop' ) : $plombiers_id;
    $plombiers_meta  = get_post_meta( $plombiers_id, 'page_type_metabox', true );
    if ($plombiers_meta && (!is_archive() || is_woocommerce_shop())) {
      $custom_title = $plombiers_meta['page_custom_title'];
      if ($custom_title) {
        $custom_title = $custom_title;
      } elseif(post_type_archive_title()) {
        post_type_archive_title();
      } else {
        $custom_title = '';
      }
    } else { $custom_title = ''; }

    if ( is_home() && is_front_page() ) {
      echo esc_html__( 'Home', 'plombiers' );
    } elseif ( is_home() && !is_front_page() ) {
      single_post_title();
    } elseif ( is_search() ) {
      printf( esc_html__( 'Search Results for %s', 'plombiers' ), '<span>' . get_search_query() . '</span>' );
    } elseif ( is_category() || is_tax() ){
      single_cat_title();
    } elseif ( is_tag() ){
      single_tag_title( esc_html__('Posts Tagged: ', 'plombiers') );
    } elseif ( is_archive() ){
      if ( is_day() ) {
        printf( wp_kses( __( 'Archive for <span>%s</span>', 'plombiers' ), array( 'span' => array() ) ), get_the_date());
      } elseif ( is_month() ) {
        printf( wp_kses( __( 'Archive for <span>%s</span>', 'plombiers' ), array( 'span' => array() )), get_the_date( 'F, Y' ));
      } elseif ( is_year() ) {
        printf( wp_kses( __( 'Archive for <span>%s</span>', 'plombiers' ), array( 'span' => array() ) ), get_the_date( 'Y' ));
      } elseif ( is_author() ) {
        printf( wp_kses( __( 'Posts by: <span>%s</span>', 'plombiers' ), array( 'span' => array() ) ), get_the_author_meta( 'display_name', $wp_query->post->post_author ));
      } elseif( is_woocommerce_shop() ) {
        echo esc_attr($custom_title);
      } elseif ( is_post_type_archive() ) {
        post_type_archive_title();
      } else {
        echo esc_html__( 'Archives', 'plombiers' );
      }
    } elseif( is_404() ) {
      echo esc_html__('404 Error', 'plombiers');
    } elseif( $custom_title ) {
      echo esc_attr($custom_title);
    } else {
      the_title();
    }

  }
}

/**
 * Pagination Function
 */
if ( ! function_exists( 'plombiers_paging_nav' ) ) {
  function plombiers_paging_nav() {
    if ( function_exists('wp_pagenavi')) {
      wp_pagenavi();
    } else {
      $older_post = cs_get_option('older_post');
      $newer_post = cs_get_option('newer_post');
      $older_post = $older_post ? $older_post : esc_html__( 'OLDER POSTS', 'plombiers' );
      $newer_post = $newer_post ? $newer_post : esc_html__( 'NEWER POSTS', 'plombiers' );
      global $wp_query;
      $big = 999999999;
      echo paginate_links( array(
        'base' => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
        'format' => '?paged=%#%',
        'prev_text' => $older_post,
        'next_text' => $newer_post,
        'current' => max( 1, get_query_var('paged') ),
        'total' => $wp_query->max_num_pages,
        'type' => 'list'
      ));
    }
  }
}


// comment submit form class
function plombiers_submit_button_comment_form( $args ) {
   $args['class_submit'] = 'btn btn-default btn-lg plmbr-button-styledark';

   return $args;
}
add_filter( 'comment_form_defaults', 'plombiers_submit_button_comment_form' );

function plombiers_video_format_data( $url ){
  $parsed = parse_url($url);
  if ( strpos( $parsed['host'], 'vimeo' ) !== false ) {
    $url = $url;
    preg_match(
        '/\/\/(www\.)?vimeo.com\/(\d+)($|\/)/',
        $url,
        $matches
    );
    $id = $matches[2];
    return $id;
  } else {
    preg_match(
        '/[\\?\\&]v=([^\\?\\&]+)/',
        $url,
        $matches
      );
      $id = $matches[1];

    return $id;
  }
}


/**
 * SINGLE PAGINATION
 */
if(!function_exists('plombiers_single_pagination')) {
  function plombiers_single_pagination() {
  $next_post = get_next_post( '', false);
  $prev_post = get_previous_post( '', false);
  $newer_post = cs_get_option('newer_post');
  $newer_post = ( $newer_post ) ? $newer_post : esc_html__('Next Article', 'plombiers');
  $older_post = cs_get_option('older_post');
  $older_post = ( $older_post ) ? $older_post : esc_html__('Previous Article', 'plombiers');
  if (empty($next_post) || empty($prev_post)) {
    $style = 'border: none;';
    $class = 'single';
  } else {
    $style = '';
    $class = '';
  }
?>
  <div class="plombiers-more-posts clearfix">
    <?php if (!empty( $prev_post )): ?>
      <div class="previous-post <?php echo esc_attr($class); ?>" style="<?php echo esc_attr( $style ); ?>">
        <a title="<?php echo esc_attr($prev_post->post_title); ?>" data-toggle="tooltip" data-placement="top"  href="<?php echo esc_url( get_permalink( $prev_post->ID ) ); ?>">
          <span class="pagination-prfix"><i class="pe-7s-prev"></i></span>
        </a>
      </div>
      <?php endif; ?>
      <?php  if (!empty( $next_post )): ?>
      <div class="next-post <?php echo esc_attr($class); ?>" style="<?php echo esc_attr( $style ); ?>">
        <a title="<?php echo esc_attr($next_post->post_title); ?>" data-toggle="tooltip" data-placement="top" href="<?php echo esc_url( get_permalink( $next_post->ID ) ); ?>">
          <span class="pagination-prfix"><i class="pe-7s-next"></i></span>
        </a>
      </div>
    <?php endif; ?>
  </div>
<?php
  }
}

if( function_exists( 'kc_add_icon' ) ) {
 add_action('init', 'plombiers_kc_custom_icon');
 function plombiers_kc_custom_icon() {
   kc_add_icon( PLOMBIERS_CSS.'/admin-pe-icon-7-icon.css' );
 }
}